"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from abbyy_document_ai.types import BaseModel
import pydantic
from typing import List, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class DangerousGoodsDeclarationFieldsShipperTypedDict(TypedDict):
    name: NotRequired[str]
    r"""The name of the shipper"""
    address: NotRequired[str]
    r"""The address of the shipper"""


class DangerousGoodsDeclarationFieldsShipper(BaseModel):
    name: Optional[str] = None
    r"""The name of the shipper"""

    address: Optional[str] = None
    r"""The address of the shipper"""


class DangerousGoodsDeclarationFieldsConsigneeTypedDict(TypedDict):
    name: NotRequired[str]
    r"""The name of the consignee"""
    address: NotRequired[str]
    r"""The address of the consignee"""


class DangerousGoodsDeclarationFieldsConsignee(BaseModel):
    name: Optional[str] = None
    r"""The name of the consignee"""

    address: Optional[str] = None
    r"""The address of the consignee"""


class DangerousGoodsDeclarationFieldsCarrierTypedDict(TypedDict):
    name: NotRequired[str]
    r"""The name of the carrier"""
    address: NotRequired[str]
    r"""The address of the carrier"""


class DangerousGoodsDeclarationFieldsCarrier(BaseModel):
    name: Optional[str] = None
    r"""The name of the carrier"""

    address: Optional[str] = None
    r"""The address of the carrier"""


class DangerousGoodsDeclarationFieldsLineItemsTypedDict(TypedDict):
    un_number: NotRequired[str]
    r"""UN-assigned four-digit number identifying the specific types of hazardous substances and materials"""
    proper_shipping_name: NotRequired[str]
    r"""Standard UN-assigned technical name describing the hazard properties and composition of dangerous goods"""
    number_of_pieces: NotRequired[float]
    r"""The number of separate packages of dangerous goods"""
    package_type: NotRequired[str]
    r"""The UN packaging identification code"""
    quantity_per_package: NotRequired[float]
    r"""The number of items in a single package"""
    unit_of_measure: NotRequired[str]
    r"""The unit of measurement for the goods"""
    class_or_division: NotRequired[str]
    r"""The ADR hazard class and subclass of dangerous goods"""
    packing_group: NotRequired[str]
    r"""The packing group of the dangerous goods (I, II, or III)"""
    packing_instruction: NotRequired[str]
    r"""The UN-assigned packing instruction number"""
    overpack_used: NotRequired[bool]
    r"""Specifies whether the packages containing dangerous goods have been placed inside an overpack"""


class DangerousGoodsDeclarationFieldsLineItems(BaseModel):
    un_number: Annotated[Optional[str], pydantic.Field(alias="unNumber")] = None
    r"""UN-assigned four-digit number identifying the specific types of hazardous substances and materials"""

    proper_shipping_name: Annotated[
        Optional[str], pydantic.Field(alias="properShippingName")
    ] = None
    r"""Standard UN-assigned technical name describing the hazard properties and composition of dangerous goods"""

    number_of_pieces: Annotated[
        Optional[float], pydantic.Field(alias="numberOfPieces")
    ] = None
    r"""The number of separate packages of dangerous goods"""

    package_type: Annotated[Optional[str], pydantic.Field(alias="packageType")] = None
    r"""The UN packaging identification code"""

    quantity_per_package: Annotated[
        Optional[float], pydantic.Field(alias="quantityPerPackage")
    ] = None
    r"""The number of items in a single package"""

    unit_of_measure: Annotated[Optional[str], pydantic.Field(alias="unitOfMeasure")] = (
        None
    )
    r"""The unit of measurement for the goods"""

    class_or_division: Annotated[
        Optional[str], pydantic.Field(alias="classOrDivision")
    ] = None
    r"""The ADR hazard class and subclass of dangerous goods"""

    packing_group: Annotated[Optional[str], pydantic.Field(alias="packingGroup")] = None
    r"""The packing group of the dangerous goods (I, II, or III)"""

    packing_instruction: Annotated[
        Optional[str], pydantic.Field(alias="packingInstruction")
    ] = None
    r"""The UN-assigned packing instruction number"""

    overpack_used: Annotated[Optional[bool], pydantic.Field(alias="overpackUsed")] = (
        None
    )
    r"""Specifies whether the packages containing dangerous goods have been placed inside an overpack"""


class CertificationTypedDict(TypedDict):
    name_of_signatory: NotRequired[str]
    r"""The name of the shipper's signatory"""
    place_and_date: NotRequired[str]
    r"""The place and date of signing"""


class Certification(BaseModel):
    name_of_signatory: Annotated[
        Optional[str], pydantic.Field(alias="nameOfSignatory")
    ] = None
    r"""The name of the shipper's signatory"""

    place_and_date: Annotated[Optional[str], pydantic.Field(alias="placeAndDate")] = (
        None
    )
    r"""The place and date of signing"""


class DangerousGoodsDeclarationFieldsTypedDict(TypedDict):
    r"""Fields extracted from a dangerous goods declaration"""

    shipper: NotRequired[DangerousGoodsDeclarationFieldsShipperTypedDict]
    consignee: NotRequired[DangerousGoodsDeclarationFieldsConsigneeTypedDict]
    carrier: NotRequired[DangerousGoodsDeclarationFieldsCarrierTypedDict]
    transportation_document_number: NotRequired[str]
    r"""The transportation document number"""
    aircraft_type: NotRequired[str]
    r"""The aircraft type"""
    airport_of_departure: NotRequired[str]
    r"""The airport of departure or port of loading"""
    airport_of_destination: NotRequired[str]
    r"""The airport of destination or port of discharge"""
    additional_handling_information: NotRequired[str]
    r"""Any additional information pertaining to safe handling of the goods"""
    shipment_type: NotRequired[str]
    r"""Specifies whether the shipment contains radioactive material (Radioactive/Non-radioactive)"""
    shippers_reference_number: NotRequired[str]
    r"""Reference number or code for tracking the goods"""
    line_items: NotRequired[List[DangerousGoodsDeclarationFieldsLineItemsTypedDict]]
    certification: NotRequired[CertificationTypedDict]
    emergency_telephone_number: NotRequired[str]
    r"""An emergency hazardous material response number"""


class DangerousGoodsDeclarationFields(BaseModel):
    r"""Fields extracted from a dangerous goods declaration"""

    shipper: Optional[DangerousGoodsDeclarationFieldsShipper] = None

    consignee: Optional[DangerousGoodsDeclarationFieldsConsignee] = None

    carrier: Optional[DangerousGoodsDeclarationFieldsCarrier] = None

    transportation_document_number: Annotated[
        Optional[str], pydantic.Field(alias="transportationDocumentNumber")
    ] = None
    r"""The transportation document number"""

    aircraft_type: Annotated[Optional[str], pydantic.Field(alias="aircraftType")] = None
    r"""The aircraft type"""

    airport_of_departure: Annotated[
        Optional[str], pydantic.Field(alias="airportOfDeparture")
    ] = None
    r"""The airport of departure or port of loading"""

    airport_of_destination: Annotated[
        Optional[str], pydantic.Field(alias="airportOfDestination")
    ] = None
    r"""The airport of destination or port of discharge"""

    additional_handling_information: Annotated[
        Optional[str], pydantic.Field(alias="additionalHandlingInformation")
    ] = None
    r"""Any additional information pertaining to safe handling of the goods"""

    shipment_type: Annotated[Optional[str], pydantic.Field(alias="shipmentType")] = None
    r"""Specifies whether the shipment contains radioactive material (Radioactive/Non-radioactive)"""

    shippers_reference_number: Annotated[
        Optional[str], pydantic.Field(alias="shippersReferenceNumber")
    ] = None
    r"""Reference number or code for tracking the goods"""

    line_items: Annotated[
        Optional[List[DangerousGoodsDeclarationFieldsLineItems]],
        pydantic.Field(alias="lineItems"),
    ] = None

    certification: Optional[Certification] = None

    emergency_telephone_number: Annotated[
        Optional[str], pydantic.Field(alias="emergencyTelephoneNumber")
    ] = None
    r"""An emergency hazardous material response number"""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .dangerousgoodsdeclarationfields import (
    DangerousGoodsDeclarationFields,
    DangerousGoodsDeclarationFieldsTypedDict,
)
from .document import Document, DocumentTypedDict
from abbyy_document_ai.types import BaseModel
import pydantic
from typing import List, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class DangerousGoodsDeclarationValidationErrorsTypedDict(TypedDict):
    message: str


class DangerousGoodsDeclarationValidationErrors(BaseModel):
    message: str


class DangerousGoodsDeclarationTypedDict(TypedDict):
    r"""Extracted Dangerous Goods Declaration Data Response"""

    meta: DocumentTypedDict
    r"""Represents a document that has been submitted for processing."""
    fields: NotRequired[DangerousGoodsDeclarationFieldsTypedDict]
    r"""Fields extracted from a dangerous goods declaration"""
    validation_errors: NotRequired[
        List[DangerousGoodsDeclarationValidationErrorsTypedDict]
    ]
    r"""An array of validation errors that occurred while processing the document. These typically do not prevent field extraction, but rather indicate issues extracting key fields."""


class DangerousGoodsDeclaration(BaseModel):
    r"""Extracted Dangerous Goods Declaration Data Response"""

    meta: Document
    r"""Represents a document that has been submitted for processing."""

    fields: Optional[DangerousGoodsDeclarationFields] = None
    r"""Fields extracted from a dangerous goods declaration"""

    validation_errors: Annotated[
        Optional[List[DangerousGoodsDeclarationValidationErrors]],
        pydantic.Field(alias="validationErrors"),
    ] = None
    r"""An array of validation errors that occurred while processing the document. These typically do not prevent field extraction, but rather indicate issues extracting key fields."""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from abbyy_document_ai.types import BaseModel
import pydantic
from typing_extensions import Annotated, TypedDict


class RawInputSourceTypedDict(TypedDict):
    r"""Input a document as a base64 encoded string."""

    base64_encoded_content: str
    r"""The base64 encoded content of the file"""
    name: str
    r"""The name of the file"""


class RawInputSource(BaseModel):
    r"""Input a document as a base64 encoded string."""

    base64_encoded_content: Annotated[str, pydantic.Field(alias="base64EncodedContent")]
    r"""The base64 encoded content of the file"""

    name: str
    r"""The name of the file"""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from abbyy_document_ai.types import BaseModel
from datetime import date
import pydantic
from typing import List, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class AccountCoOwnerNameTypedDict(TypedDict):
    account_co_owner_name: NotRequired[str]
    r"""The name of the joint account holder"""


class AccountCoOwnerName(BaseModel):
    account_co_owner_name: Annotated[
        Optional[str], pydantic.Field(alias="accountCoOwnerName")
    ] = None
    r"""The name of the joint account holder"""


class BankStatementFieldsTypedDict(TypedDict):
    r"""Fields extracted from a bank statement"""

    bank_name: NotRequired[str]
    r"""The name of the bank"""
    account_number: NotRequired[str]
    r"""The bank account number"""
    account_owner_name: NotRequired[str]
    r"""The account holder name"""
    account_owner_address: NotRequired[str]
    r"""The account holder address"""
    account_co_owner_name: NotRequired[List[AccountCoOwnerNameTypedDict]]
    currency: NotRequired[str]
    r"""The currency of the account"""
    date_of_bank_statement: NotRequired[date]
    r"""The bank statement date"""
    ending_balance_of_the_period: NotRequired[float]
    r"""The balance at the end of the reporting period"""
    ending_balance_date: NotRequired[date]
    r"""The date of the end of the reporting period"""


class BankStatementFields(BaseModel):
    r"""Fields extracted from a bank statement"""

    bank_name: Annotated[Optional[str], pydantic.Field(alias="bankName")] = None
    r"""The name of the bank"""

    account_number: Annotated[Optional[str], pydantic.Field(alias="accountNumber")] = (
        None
    )
    r"""The bank account number"""

    account_owner_name: Annotated[
        Optional[str], pydantic.Field(alias="accountOwnerName")
    ] = None
    r"""The account holder name"""

    account_owner_address: Annotated[
        Optional[str], pydantic.Field(alias="accountOwnerAddress")
    ] = None
    r"""The account holder address"""

    account_co_owner_name: Annotated[
        Optional[List[AccountCoOwnerName]], pydantic.Field(alias="accountCoOwnerName")
    ] = None

    currency: Optional[str] = None
    r"""The currency of the account"""

    date_of_bank_statement: Annotated[
        Optional[date], pydantic.Field(alias="dateOfBankStatement")
    ] = None
    r"""The bank statement date"""

    ending_balance_of_the_period: Annotated[
        Optional[float], pydantic.Field(alias="endingBalanceOfThePeriod")
    ] = None
    r"""The balance at the end of the reporting period"""

    ending_balance_date: Annotated[
        Optional[date], pydantic.Field(alias="endingBalanceDate")
    ] = None
    r"""The date of the end of the reporting period"""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from .airwaybill import (
    AirWaybill,
    AirWaybillTypedDict,
    AirWaybillValidationErrors,
    AirWaybillValidationErrorsTypedDict,
)
from .airwaybillfields import (
    AirWaybillFields,
    AirWaybillFieldsLineItems,
    AirWaybillFieldsLineItemsTypedDict,
    AirWaybillFieldsTypedDict,
    AirWaybillNumber,
    AirWaybillNumberTypedDict,
    Airline,
    AirlineTypedDict,
    AirportOfDeparture,
    AirportOfDepartureTypedDict,
    AirportOfDestination,
    AirportOfDestinationTypedDict,
    CarriersAgent,
    CarriersAgentTypedDict,
    Charges,
    ChargesTypedDict,
    Consignee,
    ConsigneeTypedDict,
    Dimensions,
    DimensionsTypedDict,
    FlightAndDate,
    FlightAndDateTypedDict,
    Shipper,
    ShipperTypedDict,
    Totals,
    TotalsTypedDict,
)
from .apierror import APIError
from .arrivalnotice import (
    ArrivalNotice,
    ArrivalNoticeTypedDict,
    ArrivalNoticeValidationErrors,
    ArrivalNoticeValidationErrorsTypedDict,
)
from .arrivalnoticefields import (
    Amount,
    AmountTypedDict,
    ArrivalNoticeFields,
    ArrivalNoticeFieldsBillTo,
    ArrivalNoticeFieldsBillToTypedDict,
    ArrivalNoticeFieldsConsignee,
    ArrivalNoticeFieldsConsigneeTypedDict,
    ArrivalNoticeFieldsShipper,
    ArrivalNoticeFieldsShipperTypedDict,
    ArrivalNoticeFieldsTypedDict,
    Carrier,
    CarrierTypedDict,
    Containers,
    ContainersNotInTable,
    ContainersNotInTableTypedDict,
    ContainersTypedDict,
    NotifyParty,
    NotifyPartyTypedDict,
    Packages,
    PackagesTypedDict,
    Terms,
    TermsTypedDict,
    Volume,
    VolumeTypedDict,
    Weight,
    WeightTypedDict,
)
from .badrequesterror import (
    BadRequestError,
    BadRequestErrorData,
    Comparison,
    Comparison1,
    Comparison2,
    Comparison3,
    Comparison4,
    Eight,
    EightTypedDict,
    Eleven,
    ElevenTypedDict,
    Nine,
    NineTypedDict,
    Params,
    Params1,
    Params1TypedDict,
    Params2,
    Params2TypedDict,
    Params3,
    Params3TypedDict,
    Params4,
    Params4TypedDict,
    Params5,
    Params5TypedDict,
    Seven,
    SevenTypedDict,
    Six,
    SixTypedDict,
    Ten,
    TenTypedDict,
    Validation,
    ValidationContext,
    ValidationTypedDict,
)
from .bankstatement import (
    BankStatement,
    BankStatementTypedDict,
    BankStatementValidationErrors,
    BankStatementValidationErrorsTypedDict,
)
from .bankstatementfields import (
    AccountCoOwnerName,
    AccountCoOwnerNameTypedDict,
    BankStatementFields,
    BankStatementFieldsTypedDict,
)
from .basiccontract import (
    BasicContract,
    BasicContractTypedDict,
    BasicContractValidationErrors,
    BasicContractValidationErrorsTypedDict,
)
from .basiccontractfields import (
    BasicContractFields,
    BasicContractFieldsTypedDict,
    Party,
    PartyTypedDict,
)
from .beginairwaybillfieldextractionop import (
    BeginAirWaybillFieldExtractionResponse,
    BeginAirWaybillFieldExtractionResponseTypedDict,
)
from .beginairwaybillfieldextractionrequestbody import (
    BeginAirWaybillFieldExtractionRequestBody,
    BeginAirWaybillFieldExtractionRequestBodyTypedDict,
)
from .beginarrivalnoticefieldextractionop import (
    BeginArrivalNoticeFieldExtractionResponse,
    BeginArrivalNoticeFieldExtractionResponseTypedDict,
)
from .beginarrivalnoticefieldextractionrequestbody import (
    BeginArrivalNoticeFieldExtractionRequestBody,
    BeginArrivalNoticeFieldExtractionRequestBodyTypedDict,
)
from .beginbankstatementfieldextractionop import (
    BeginBankStatementFieldExtractionResponse,
    BeginBankStatementFieldExtractionResponseTypedDict,
)
from .beginbankstatementfieldextractionrequestbody import (
    BeginBankStatementFieldExtractionRequestBody,
    BeginBankStatementFieldExtractionRequestBodyTypedDict,
)
from .beginbasiccontractfieldextractionop import (
    BeginBasicContractFieldExtractionResponse,
    BeginBasicContractFieldExtractionResponseTypedDict,
)
from .beginbasiccontractfieldextractionrequestbody import (
    BeginBasicContractFieldExtractionRequestBody,
    BeginBasicContractFieldExtractionRequestBodyTypedDict,
)
from .beginbillofladingfieldextractionop import (
    BeginBillOfLadingFieldExtractionResponse,
    BeginBillOfLadingFieldExtractionResponseTypedDict,
)
from .beginbillofladingfieldextractionrequestbody import (
    BeginBillOfLadingFieldExtractionRequestBody,
    BeginBillOfLadingFieldExtractionRequestBodyTypedDict,
)
from .beginbrokeragestatementfieldextractionop import (
    BeginBrokerageStatementFieldExtractionResponse,
    BeginBrokerageStatementFieldExtractionResponseTypedDict,
)
from .beginbrokeragestatementfieldextractionrequestbody import (
    BeginBrokerageStatementFieldExtractionRequestBody,
    BeginBrokerageStatementFieldExtractionRequestBodyTypedDict,
)
from .begincertificateoforiginfieldextractionop import (
    BeginCertificateOfOriginFieldExtractionResponse,
    BeginCertificateOfOriginFieldExtractionResponseTypedDict,
)
from .begincertificateoforiginfieldextractionrequestbody import (
    BeginCertificateOfOriginFieldExtractionRequestBody,
    BeginCertificateOfOriginFieldExtractionRequestBodyTypedDict,
)
from .begincommercialinvoicefieldextractionop import (
    BeginCommercialInvoiceFieldExtractionResponse,
    BeginCommercialInvoiceFieldExtractionResponseTypedDict,
)
from .begincommercialinvoicefieldextractionrequestbody import (
    BeginCommercialInvoiceFieldExtractionRequestBody,
    BeginCommercialInvoiceFieldExtractionRequestBodyTypedDict,
)
from .begincustomsdeclarationfieldextractionop import (
    BeginCustomsDeclarationFieldExtractionResponse,
    BeginCustomsDeclarationFieldExtractionResponseTypedDict,
)
from .begincustomsdeclarationfieldextractionrequestbody import (
    BeginCustomsDeclarationFieldExtractionRequestBody,
    BeginCustomsDeclarationFieldExtractionRequestBodyTypedDict,
)
from .begindangerousgoodsdeclarationfieldextractionop import (
    BeginDangerousGoodsDeclarationFieldExtractionResponse,
    BeginDangerousGoodsDeclarationFieldExtractionResponseTypedDict,
)
from .begindangerousgoodsdeclarationfieldextractionrequestbody import (
    BeginDangerousGoodsDeclarationFieldExtractionRequestBody,
    BeginDangerousGoodsDeclarationFieldExtractionRequestBodyTypedDict,
)
from .begindeliverynotefieldextractionop import (
    BeginDeliveryNoteFieldExtractionResponse,
    BeginDeliveryNoteFieldExtractionResponseTypedDict,
)
from .begindeliverynotefieldextractionrequestbody import (
    BeginDeliveryNoteFieldExtractionRequestBody,
    BeginDeliveryNoteFieldExtractionRequestBodyTypedDict,
)
from .begindocumentconversiondocumentconversionop import (
    BeginDocumentConversionDocumentConversionResponse,
    BeginDocumentConversionDocumentConversionResponseTypedDict,
)
from .begindocumentconversiondocumentconversionrequestbody import (
    BeginDocumentConversionDocumentConversionRequestBody,
    BeginDocumentConversionDocumentConversionRequestBodyTypedDict,
    DocumentConversionOutputFormat,
    Languages,
    Options,
    OptionsTypedDict,
)
from .beginhotelinvoicefieldextractionop import (
    BeginHotelInvoiceFieldExtractionResponse,
    BeginHotelInvoiceFieldExtractionResponseTypedDict,
)
from .beginhotelinvoicefieldextractionrequestbody import (
    BeginHotelInvoiceFieldExtractionRequestBody,
    BeginHotelInvoiceFieldExtractionRequestBodyTypedDict,
)
from .beginimagetotexttextextractionop import (
    BeginImageToTextTextExtractionResponse,
    BeginImageToTextTextExtractionResponseTypedDict,
)
from .beginimagetotexttextextractionrequestbody import (
    BeginImageToTextTextExtractionRequestBody,
    BeginImageToTextTextExtractionRequestBodyLanguages,
    BeginImageToTextTextExtractionRequestBodyOptions,
    BeginImageToTextTextExtractionRequestBodyOptionsTypedDict,
    BeginImageToTextTextExtractionRequestBodyTypedDict,
)
from .begininternationalconsignmentnotefieldextractionop import (
    BeginInternationalConsignmentNoteFieldExtractionResponse,
    BeginInternationalConsignmentNoteFieldExtractionResponseTypedDict,
)
from .begininternationalconsignmentnotefieldextractionrequestbody import (
    BeginInternationalConsignmentNoteFieldExtractionRequestBody,
    BeginInternationalConsignmentNoteFieldExtractionRequestBodyTypedDict,
)
from .begininvoicefieldextractionop import (
    BeginInvoiceFieldExtractionResponse,
    BeginInvoiceFieldExtractionResponseTypedDict,
)
from .begininvoicefieldextractionrequestbody import (
    BeginInvoiceFieldExtractionRequestBody,
    BeginInvoiceFieldExtractionRequestBodyTypedDict,
)
from .beginpackinglistfieldextractionop import (
    BeginPackingListFieldExtractionResponse,
    BeginPackingListFieldExtractionResponseTypedDict,
)
from .beginpackinglistfieldextractionrequestbody import (
    BeginPackingListFieldExtractionRequestBody,
    BeginPackingListFieldExtractionRequestBodyTypedDict,
)
from .beginpersonalearningsstatementfieldextractionop import (
    BeginPersonalEarningsStatementFieldExtractionResponse,
    BeginPersonalEarningsStatementFieldExtractionResponseTypedDict,
)
from .beginpersonalearningsstatementfieldextractionrequestbody import (
    BeginPersonalEarningsStatementFieldExtractionRequestBody,
    BeginPersonalEarningsStatementFieldExtractionRequestBodyTypedDict,
)
from .beginpurchaseorderfieldextractionop import (
    BeginPurchaseOrderFieldExtractionResponse,
    BeginPurchaseOrderFieldExtractionResponseTypedDict,
)
from .beginpurchaseorderfieldextractionrequestbody import (
    BeginPurchaseOrderFieldExtractionRequestBody,
    BeginPurchaseOrderFieldExtractionRequestBodyTypedDict,
)
from .beginreceiptfieldextractionop import (
    BeginReceiptFieldExtractionResponse,
    BeginReceiptFieldExtractionResponseTypedDict,
)
from .beginreceiptfieldextractionrequestbody import (
    BeginReceiptFieldExtractionRequestBody,
    BeginReceiptFieldExtractionRequestBodyTypedDict,
)
from .beginremittanceadvicefieldextractionop import (
    BeginRemittanceAdviceFieldExtractionResponse,
    BeginRemittanceAdviceFieldExtractionResponseTypedDict,
)
from .beginremittanceadvicefieldextractionrequestbody import (
    BeginRemittanceAdviceFieldExtractionRequestBody,
    BeginRemittanceAdviceFieldExtractionRequestBodyTypedDict,
)
from .beginseawaybillfieldextractionop import (
    BeginSeaWaybillFieldExtractionResponse,
    BeginSeaWaybillFieldExtractionResponseTypedDict,
)
from .beginseawaybillfieldextractionrequestbody import (
    BeginSeaWaybillFieldExtractionRequestBody,
    BeginSeaWaybillFieldExtractionRequestBodyTypedDict,
)
from .begintaxireceiptfieldextractionop import (
    BeginTaxiReceiptFieldExtractionResponse,
    BeginTaxiReceiptFieldExtractionResponseTypedDict,
)
from .begintaxireceiptfieldextractionrequestbody import (
    BeginTaxiReceiptFieldExtractionRequestBody,
    BeginTaxiReceiptFieldExtractionRequestBodyTypedDict,
)
from .beginusform1040fieldextractionop import (
    BeginUsForm1040FieldExtractionResponse,
    BeginUsForm1040FieldExtractionResponseTypedDict,
)
from .beginusform1040fieldextractionrequestbody import (
    BeginUsForm1040FieldExtractionRequestBody,
    BeginUsForm1040FieldExtractionRequestBodyTypedDict,
)
from .beginusformw2fieldextractionop import (
    BeginUsFormW2FieldExtractionResponse,
    BeginUsFormW2FieldExtractionResponseTypedDict,
)
from .beginusformw2fieldextractionrequestbody import (
    BeginUsFormW2FieldExtractionRequestBody,
    BeginUsFormW2FieldExtractionRequestBodyTypedDict,
)
from .beginutilitybillfieldextractionop import (
    BeginUtilityBillFieldExtractionResponse,
    BeginUtilityBillFieldExtractionResponseTypedDict,
)
from .beginutilitybillfieldextractionrequestbody import (
    BeginUtilityBillFieldExtractionRequestBody,
    BeginUtilityBillFieldExtractionRequestBodyTypedDict,
)
from .billoflading import (
    BillOfLading,
    BillOfLadingTypedDict,
    BillOfLadingValidationErrors,
    BillOfLadingValidationErrorsTypedDict,
)
from .billofladingfields import (
    BillOfLadingFields,
    BillOfLadingFieldsBillTo,
    BillOfLadingFieldsBillToTypedDict,
    BillOfLadingFieldsCarrier,
    BillOfLadingFieldsCarrierTypedDict,
    BillOfLadingFieldsConsignee,
    BillOfLadingFieldsConsigneeTypedDict,
    BillOfLadingFieldsShipper,
    BillOfLadingFieldsShipperTypedDict,
    BillOfLadingFieldsTerms,
    BillOfLadingFieldsTermsTypedDict,
    BillOfLadingFieldsTypedDict,
)
from .brokeragestatement import (
    BrokerageStatement,
    BrokerageStatementTypedDict,
    BrokerageStatementValidationErrors,
    BrokerageStatementValidationErrorsTypedDict,
)
from .brokeragestatementfields import (
    Advisor,
    AdvisorTypedDict,
    Broker,
    BrokerTypedDict,
    BrokerageStatementFields,
    BrokerageStatementFieldsTypedDict,
    Client,
    ClientTypedDict,
    HoldingsLevel,
    HoldingsLevelTypedDict,
    Transactions,
    TransactionsTypedDict,
)
from .certificateoforigin import (
    CertificateOfOrigin,
    CertificateOfOriginTypedDict,
    CertificateOfOriginValidationErrors,
    CertificateOfOriginValidationErrorsTypedDict,
)
from .certificateoforiginfields import (
    CertificateOfOriginFields,
    CertificateOfOriginFieldsConsignee,
    CertificateOfOriginFieldsConsigneeTypedDict,
    CertificateOfOriginFieldsLineItems,
    CertificateOfOriginFieldsLineItemsTypedDict,
    CertificateOfOriginFieldsTypedDict,
    Exporter,
    ExporterTypedDict,
    InvoiceNumbers,
    InvoiceNumbersTypedDict,
    MeansOfTransportAndRoute,
    MeansOfTransportAndRouteTypedDict,
)
from .commercialinvoice import (
    CommercialInvoice,
    CommercialInvoiceTypedDict,
    CommercialInvoiceValidationErrors,
    CommercialInvoiceValidationErrorsTypedDict,
)
from .commercialinvoicefields import (
    CommercialInvoiceFields,
    CommercialInvoiceFieldsAdditionalCosts,
    CommercialInvoiceFieldsAdditionalCostsTypedDict,
    CommercialInvoiceFieldsBillTo,
    CommercialInvoiceFieldsBillToTypedDict,
    CommercialInvoiceFieldsConsignee,
    CommercialInvoiceFieldsConsigneeTypedDict,
    CommercialInvoiceFieldsLineItems,
    CommercialInvoiceFieldsLineItemsTypedDict,
    CommercialInvoiceFieldsShipTo,
    CommercialInvoiceFieldsShipToTypedDict,
    CommercialInvoiceFieldsTypedDict,
    CommercialInvoiceFieldsVendor,
    CommercialInvoiceFieldsVendorTypedDict,
)
from .contenttoolargeerror import ContentTooLargeError, ContentTooLargeErrorData
from .conversionresults import ConversionResults, ConversionResultsTypedDict
from .customsdeclaration import (
    CustomsDeclaration,
    CustomsDeclarationTypedDict,
    CustomsDeclarationValidationErrors,
    CustomsDeclarationValidationErrorsTypedDict,
)
from .customsdeclarationfields import (
    Consignor,
    ConsignorTypedDict,
    ControlByOfficeOfDispatch,
    ControlByOfficeOfDispatchTypedDict,
    CustomsDeclarationFields,
    CustomsDeclarationFieldsConsignee,
    CustomsDeclarationFieldsConsigneeTypedDict,
    CustomsDeclarationFieldsTypedDict,
    Declarant,
    DeclarantTypedDict,
    DeclarationType,
    DeclarationTypeTypedDict,
    Forms,
    FormsTypedDict,
    ReferenceNumber,
    ReferenceNumberTypedDict,
)
from .dangerousgoodsdeclaration import (
    DangerousGoodsDeclaration,
    DangerousGoodsDeclarationTypedDict,
    DangerousGoodsDeclarationValidationErrors,
    DangerousGoodsDeclarationValidationErrorsTypedDict,
)
from .dangerousgoodsdeclarationfields import (
    Certification,
    CertificationTypedDict,
    DangerousGoodsDeclarationFields,
    DangerousGoodsDeclarationFieldsCarrier,
    DangerousGoodsDeclarationFieldsCarrierTypedDict,
    DangerousGoodsDeclarationFieldsConsignee,
    DangerousGoodsDeclarationFieldsConsigneeTypedDict,
    DangerousGoodsDeclarationFieldsLineItems,
    DangerousGoodsDeclarationFieldsLineItemsTypedDict,
    DangerousGoodsDeclarationFieldsShipper,
    DangerousGoodsDeclarationFieldsShipperTypedDict,
    DangerousGoodsDeclarationFieldsTypedDict,
)
from .deletedocumentop import (
    DeleteDocumentRequest,
    DeleteDocumentRequestTypedDict,
    DeleteDocumentResponse,
    DeleteDocumentResponseTypedDict,
)
from .deliverynote import (
    DeliveryNote,
    DeliveryNoteTypedDict,
    DeliveryNoteValidationErrors,
    DeliveryNoteValidationErrorsTypedDict,
)
from .deliverynotefields import (
    AdditionalCosts,
    AdditionalCostsTypedDict,
    Amounts,
    AmountsTypedDict,
    DeliveryNoteFields,
    DeliveryNoteFieldsBillTo,
    DeliveryNoteFieldsBillToTypedDict,
    DeliveryNoteFieldsBuyer,
    DeliveryNoteFieldsBuyerTypedDict,
    DeliveryNoteFieldsLineItems,
    DeliveryNoteFieldsLineItemsTypedDict,
    DeliveryNoteFieldsShipTo,
    DeliveryNoteFieldsShipToTypedDict,
    DeliveryNoteFieldsTaxes,
    DeliveryNoteFieldsTaxesTypedDict,
    DeliveryNoteFieldsTypedDict,
    DeliveryNoteFieldsVendor,
    DeliveryNoteFieldsVendorTypedDict,
)
from .document import Document, DocumentTypedDict, Errors, ErrorsTypedDict, Status
from .downloaddocumentconversionconverteddocumentop import (
    DownloadDocumentConversionConvertedDocumentRequest,
    DownloadDocumentConversionConvertedDocumentRequestTypedDict,
    DownloadDocumentConversionConvertedDocumentResponse,
    DownloadDocumentConversionConvertedDocumentResponseTypedDict,
    PathParamDocumentConversionOutputFormat,
)
from .extractedtext import (
    Aligning,
    B,
    Barcodes,
    BarcodesTypedDict,
    BlockType,
    Borders,
    BordersTypedDict,
    Cells,
    CellsTypedDict,
    CharParams,
    CharParamsTypedDict,
    Chars,
    CharsTypedDict,
    Checkmarks,
    CheckmarksTypedDict,
    ColRowPosition,
    ColRowPositionTypedDict,
    Content,
    ContentType,
    ContentTypedDict,
    EndPoints,
    EndPointsTypedDict,
    ExtractedText,
    ExtractedTextCharParams,
    ExtractedTextCharParamsTypedDict,
    ExtractedTextChars,
    ExtractedTextCharsTypedDict,
    ExtractedTextLines,
    ExtractedTextLinesTypedDict,
    ExtractedTextPosition,
    ExtractedTextPositionTypedDict,
    ExtractedTextTextLayoutPagesPosition,
    ExtractedTextTextLayoutPagesPositionTypedDict,
    ExtractedTextTextLayoutPagesSeparatorsPosition,
    ExtractedTextTextLayoutPagesSeparatorsPositionTypedDict,
    ExtractedTextTextLayoutPagesTablesCellsLinesPosition,
    ExtractedTextTextLayoutPagesTablesCellsLinesPositionTypedDict,
    ExtractedTextTextLayoutPagesTablesCellsLinesWordsPosition,
    ExtractedTextTextLayoutPagesTablesCellsLinesWordsPositionTypedDict,
    ExtractedTextTextLayoutPagesTablesCellsPosition,
    ExtractedTextTextLayoutPagesTablesCellsPositionTypedDict,
    ExtractedTextTextLayoutPagesTablesPosition,
    ExtractedTextTextLayoutPagesTablesPositionTypedDict,
    ExtractedTextTextLayoutPagesTextsLinesPosition,
    ExtractedTextTextLayoutPagesTextsLinesPositionTypedDict,
    ExtractedTextTextLayoutPagesTextsLinesWordsPosition,
    ExtractedTextTextLayoutPagesTextsLinesWordsPositionTypedDict,
    ExtractedTextTextLayoutPagesTextsPosition,
    ExtractedTextTextLayoutPagesTextsPositionTypedDict,
    ExtractedTextTextLayoutPosition,
    ExtractedTextTextLayoutPositionTypedDict,
    ExtractedTextTextPosition,
    ExtractedTextTextPositionTypedDict,
    ExtractedTextTextType,
    ExtractedTextType,
    ExtractedTextTypedDict,
    ExtractedTextWords,
    ExtractedTextWordsTypedDict,
    Formatting,
    FormattingTypedDict,
    L,
    Layout,
    LayoutReferences,
    LayoutReferencesTypedDict,
    LayoutTypedDict,
    Lines,
    LinesTypedDict,
    ListLevels,
    ListLevelsTypedDict,
    ListReference,
    ListReferenceTypedDict,
    Lists,
    ListsTypedDict,
    NumberingStyle,
    Pages,
    PagesTypedDict,
    Paragraphs,
    ParagraphsTypedDict,
    Pictures,
    PicturesTypedDict,
    Position,
    PositionTypedDict,
    R,
    Role,
    Rotated,
    Separators,
    SeparatorsTypedDict,
    SupplementType,
    T,
    Tables,
    TablesTypedDict,
    Text,
    TextTypedDict,
    Texts,
    TextsTypedDict,
    Value,
    Words,
    WordsTypedDict,
)
from .getdocumentconversionconversionop import (
    GetDocumentConversionConversionRequest,
    GetDocumentConversionConversionRequestTypedDict,
    GetDocumentConversionConversionResponse,
    GetDocumentConversionConversionResponseTypedDict,
)
from .getextractedairwaybillfieldsop import (
    GetExtractedAirWaybillFieldsRequest,
    GetExtractedAirWaybillFieldsRequestTypedDict,
    GetExtractedAirWaybillFieldsResponse,
    GetExtractedAirWaybillFieldsResponseTypedDict,
)
from .getextractedarrivalnoticefieldsop import (
    GetExtractedArrivalNoticeFieldsRequest,
    GetExtractedArrivalNoticeFieldsRequestTypedDict,
    GetExtractedArrivalNoticeFieldsResponse,
    GetExtractedArrivalNoticeFieldsResponseTypedDict,
)
from .getextractedbankstatementfieldsop import (
    GetExtractedBankStatementFieldsRequest,
    GetExtractedBankStatementFieldsRequestTypedDict,
    GetExtractedBankStatementFieldsResponse,
    GetExtractedBankStatementFieldsResponseTypedDict,
)
from .getextractedbasiccontractfieldsop import (
    GetExtractedBasicContractFieldsRequest,
    GetExtractedBasicContractFieldsRequestTypedDict,
    GetExtractedBasicContractFieldsResponse,
    GetExtractedBasicContractFieldsResponseTypedDict,
)
from .getextractedbillofladingfieldsop import (
    GetExtractedBillOfLadingFieldsRequest,
    GetExtractedBillOfLadingFieldsRequestTypedDict,
    GetExtractedBillOfLadingFieldsResponse,
    GetExtractedBillOfLadingFieldsResponseTypedDict,
)
from .getextractedbrokeragestatementfieldsop import (
    GetExtractedBrokerageStatementFieldsRequest,
    GetExtractedBrokerageStatementFieldsRequestTypedDict,
    GetExtractedBrokerageStatementFieldsResponse,
    GetExtractedBrokerageStatementFieldsResponseTypedDict,
)
from .getextractedcertificateoforiginfieldsop import (
    GetExtractedCertificateOfOriginFieldsRequest,
    GetExtractedCertificateOfOriginFieldsRequestTypedDict,
    GetExtractedCertificateOfOriginFieldsResponse,
    GetExtractedCertificateOfOriginFieldsResponseTypedDict,
)
from .getextractedcommercialinvoicefieldsop import (
    GetExtractedCommercialInvoiceFieldsRequest,
    GetExtractedCommercialInvoiceFieldsRequestTypedDict,
    GetExtractedCommercialInvoiceFieldsResponse,
    GetExtractedCommercialInvoiceFieldsResponseTypedDict,
)
from .getextractedcustomsdeclarationfieldsop import (
    GetExtractedCustomsDeclarationFieldsRequest,
    GetExtractedCustomsDeclarationFieldsRequestTypedDict,
    GetExtractedCustomsDeclarationFieldsResponse,
    GetExtractedCustomsDeclarationFieldsResponseTypedDict,
)
from .getextracteddangerousgoodsdeclarationfieldsop import (
    GetExtractedDangerousGoodsDeclarationFieldsRequest,
    GetExtractedDangerousGoodsDeclarationFieldsRequestTypedDict,
    GetExtractedDangerousGoodsDeclarationFieldsResponse,
    GetExtractedDangerousGoodsDeclarationFieldsResponseTypedDict,
)
from .getextracteddeliverynotefieldsop import (
    GetExtractedDeliveryNoteFieldsRequest,
    GetExtractedDeliveryNoteFieldsRequestTypedDict,
    GetExtractedDeliveryNoteFieldsResponse,
    GetExtractedDeliveryNoteFieldsResponseTypedDict,
)
from .getextractedhotelinvoicefieldsop import (
    GetExtractedHotelInvoiceFieldsRequest,
    GetExtractedHotelInvoiceFieldsRequestTypedDict,
    GetExtractedHotelInvoiceFieldsResponse,
    GetExtractedHotelInvoiceFieldsResponseTypedDict,
)
from .getextractedinternationalconsignmentnotefieldsop import (
    GetExtractedInternationalConsignmentNoteFieldsRequest,
    GetExtractedInternationalConsignmentNoteFieldsRequestTypedDict,
    GetExtractedInternationalConsignmentNoteFieldsResponse,
    GetExtractedInternationalConsignmentNoteFieldsResponseTypedDict,
)
from .getextractedinvoicefieldsop import (
    GetExtractedInvoiceFieldsRequest,
    GetExtractedInvoiceFieldsRequestTypedDict,
    GetExtractedInvoiceFieldsResponse,
    GetExtractedInvoiceFieldsResponseTypedDict,
)
from .getextractedpackinglistfieldsop import (
    GetExtractedPackingListFieldsRequest,
    GetExtractedPackingListFieldsRequestTypedDict,
    GetExtractedPackingListFieldsResponse,
    GetExtractedPackingListFieldsResponseTypedDict,
)
from .getextractedpersonalearningsstatementfieldsop import (
    GetExtractedPersonalEarningsStatementFieldsRequest,
    GetExtractedPersonalEarningsStatementFieldsRequestTypedDict,
    GetExtractedPersonalEarningsStatementFieldsResponse,
    GetExtractedPersonalEarningsStatementFieldsResponseTypedDict,
)
from .getextractedpurchaseorderfieldsop import (
    GetExtractedPurchaseOrderFieldsRequest,
    GetExtractedPurchaseOrderFieldsRequestTypedDict,
    GetExtractedPurchaseOrderFieldsResponse,
    GetExtractedPurchaseOrderFieldsResponseTypedDict,
)
from .getextractedreceiptfieldsop import (
    GetExtractedReceiptFieldsRequest,
    GetExtractedReceiptFieldsRequestTypedDict,
    GetExtractedReceiptFieldsResponse,
    GetExtractedReceiptFieldsResponseTypedDict,
)
from .getextractedremittanceadvicefieldsop import (
    GetExtractedRemittanceAdviceFieldsRequest,
    GetExtractedRemittanceAdviceFieldsRequestTypedDict,
    GetExtractedRemittanceAdviceFieldsResponse,
    GetExtractedRemittanceAdviceFieldsResponseTypedDict,
)
from .getextractedseawaybillfieldsop import (
    GetExtractedSeaWaybillFieldsRequest,
    GetExtractedSeaWaybillFieldsRequestTypedDict,
    GetExtractedSeaWaybillFieldsResponse,
    GetExtractedSeaWaybillFieldsResponseTypedDict,
)
from .getextractedtaxireceiptfieldsop import (
    GetExtractedTaxiReceiptFieldsRequest,
    GetExtractedTaxiReceiptFieldsRequestTypedDict,
    GetExtractedTaxiReceiptFieldsResponse,
    GetExtractedTaxiReceiptFieldsResponseTypedDict,
)
from .getextractedusform1040fieldsop import (
    GetExtractedUsForm1040FieldsRequest,
    GetExtractedUsForm1040FieldsRequestTypedDict,
    GetExtractedUsForm1040FieldsResponse,
    GetExtractedUsForm1040FieldsResponseTypedDict,
)
from .getextractedusformw2fieldsop import (
    GetExtractedUsFormW2FieldsRequest,
    GetExtractedUsFormW2FieldsRequestTypedDict,
    GetExtractedUsFormW2FieldsResponse,
    GetExtractedUsFormW2FieldsResponseTypedDict,
)
from .getextractedutilitybillfieldsop import (
    GetExtractedUtilityBillFieldsRequest,
    GetExtractedUtilityBillFieldsRequestTypedDict,
    GetExtractedUtilityBillFieldsResponse,
    GetExtractedUtilityBillFieldsResponseTypedDict,
)
from .getimagetotextextractedtextop import (
    GetImageToTextExtractedTextRequest,
    GetImageToTextExtractedTextRequestTypedDict,
    GetImageToTextExtractedTextResponse,
    GetImageToTextExtractedTextResponseTypedDict,
)
from .hotelinvoice import (
    HotelInvoice,
    HotelInvoiceTypedDict,
    HotelInvoiceValidationErrors,
    HotelInvoiceValidationErrorsTypedDict,
)
from .hotelinvoicefields import (
    CardType,
    CardType1,
    CardType2,
    CardType3,
    CardType4,
    CardType5,
    CardTypeTypedDict,
    CreditOrDebit,
    CreditOrDebit1,
    CreditOrDebit2,
    CreditOrDebitTypedDict,
    Five,
    Four,
    HotelInvoiceFields,
    HotelInvoiceFieldsLineItems,
    HotelInvoiceFieldsLineItemsTypedDict,
    HotelInvoiceFieldsTaxes,
    HotelInvoiceFieldsTaxesTypedDict,
    HotelInvoiceFieldsTypedDict,
    One,
    PaymentMethod,
    PaymentMethodTypedDict,
    Three,
    Two,
)
from .httpmetadata import HTTPMetadata, HTTPMetadataTypedDict
from .inputsource import InputSource, InputSourceTypedDict
from .internalservererror import InternalServerError, InternalServerErrorData
from .internationalconsignmentnote import (
    InternationalConsignmentNote,
    InternationalConsignmentNoteTypedDict,
    InternationalConsignmentNoteValidationErrors,
    InternationalConsignmentNoteValidationErrorsTypedDict,
)
from .internationalconsignmentnotefields import (
    Discharge,
    DischargeTypedDict,
    InternationalConsignmentNoteFields,
    InternationalConsignmentNoteFieldsCarrier,
    InternationalConsignmentNoteFieldsCarrierTypedDict,
    InternationalConsignmentNoteFieldsConsignee,
    InternationalConsignmentNoteFieldsConsigneeTypedDict,
    InternationalConsignmentNoteFieldsLineItems,
    InternationalConsignmentNoteFieldsLineItemsTypedDict,
    InternationalConsignmentNoteFieldsShipper,
    InternationalConsignmentNoteFieldsShipperTypedDict,
    InternationalConsignmentNoteFieldsTotals,
    InternationalConsignmentNoteFieldsTotalsTypedDict,
    InternationalConsignmentNoteFieldsTypedDict,
    Loading,
    LoadingTypedDict,
    PlaceAndDateOfTakingOverOfGoods,
    PlaceAndDateOfTakingOverOfGoodsTypedDict,
    PlaceOfDeliveryOfGoods,
    PlaceOfDeliveryOfGoodsTypedDict,
    SuccessiveCarrier,
    SuccessiveCarrierTypedDict,
)
from .invoice import (
    Invoice,
    InvoiceTypedDict,
    InvoiceValidationErrors,
    InvoiceValidationErrorsTypedDict,
)
from .invoicefields import (
    BusinessUnit,
    BusinessUnitTypedDict,
    InvoiceData,
    InvoiceDataTypedDict,
    InvoiceFields,
    InvoiceFieldsPurchaseOrder,
    InvoiceFieldsPurchaseOrderTypedDict,
    InvoiceFieldsTaxes,
    InvoiceFieldsTaxesTypedDict,
    InvoiceFieldsTypedDict,
    InvoiceType,
    InvoiceTypeTypedDict,
    LineItems,
    LineItemsTypedDict,
    TaxRates,
    TaxRatesTypedDict,
    Vendor,
    VendorTypedDict,
)
from .listdocumentsop import (
    ListDocumentsRequest,
    ListDocumentsRequestTypedDict,
    ListDocumentsResponse,
    ListDocumentsResponseTypedDict,
)
from .notfounderror import NotFoundError, NotFoundErrorData
from .packinglist import (
    PackingList,
    PackingListTypedDict,
    PackingListValidationErrors,
    PackingListValidationErrorsTypedDict,
)
from .packinglistfields import (
    PackingListFields,
    PackingListFieldsBillTo,
    PackingListFieldsBillToTypedDict,
    PackingListFieldsBuyer,
    PackingListFieldsBuyerTypedDict,
    PackingListFieldsConsignee,
    PackingListFieldsConsigneeTypedDict,
    PackingListFieldsLineItems,
    PackingListFieldsLineItemsTypedDict,
    PackingListFieldsPurchaseOrder,
    PackingListFieldsPurchaseOrderTypedDict,
    PackingListFieldsShipper,
    PackingListFieldsShipperTypedDict,
    PackingListFieldsTypedDict,
    TotalDimensions,
    TotalDimensionsTypedDict,
    TotalGrossWeight,
    TotalGrossWeightTypedDict,
    TotalNetWeight,
    TotalNetWeightTypedDict,
    TotalPackages,
    TotalPackagesTypedDict,
    TotalQuantity,
    TotalQuantityTypedDict,
    TotalVolume,
    TotalVolumeTypedDict,
)
from .paymentrequirederror import PaymentRequiredError, PaymentRequiredErrorData
from .personalearningsstatement import (
    PersonalEarningsStatement,
    PersonalEarningsStatementTypedDict,
    PersonalEarningsStatementValidationErrors,
    PersonalEarningsStatementValidationErrorsTypedDict,
)
from .personalearningsstatementfields import (
    PersonalEarningsStatementFields,
    PersonalEarningsStatementFieldsTypedDict,
)
from .problemdetail import ProblemDetail, ProblemDetailData
from .purchaseorder import (
    PurchaseOrder,
    PurchaseOrderTypedDict,
    PurchaseOrderValidationErrors,
    PurchaseOrderValidationErrorsTypedDict,
)
from .purchaseorderfields import (
    BillTo,
    BillToTypedDict,
    Buyer,
    BuyerTypedDict,
    PurchaseOrderFields,
    PurchaseOrderFieldsLineItems,
    PurchaseOrderFieldsLineItemsTypedDict,
    PurchaseOrderFieldsTaxes,
    PurchaseOrderFieldsTaxesTypedDict,
    PurchaseOrderFieldsTypedDict,
    ShipTo,
    ShipToTypedDict,
    Supplier,
    SupplierTypedDict,
)
from .rawinputsource import RawInputSource, RawInputSourceTypedDict
from .receipt import (
    Receipt,
    ReceiptTypedDict,
    ValidationErrors,
    ValidationErrorsTypedDict,
)
from .receiptfields import (
    ExpenseType,
    ExpenseTypeTypedDict,
    ReceiptFields,
    ReceiptFieldsTypedDict,
    ReceiptLineItem,
    ReceiptLineItemTypedDict,
    Taxes,
    TaxesTypedDict,
)
from .remittanceadvice import (
    RemittanceAdvice,
    RemittanceAdviceTypedDict,
    RemittanceAdviceValidationErrors,
    RemittanceAdviceValidationErrorsTypedDict,
)
from .remittanceadvicefields import (
    Customer,
    CustomerTypedDict,
    PaymentInformation,
    PaymentInformationTypedDict,
    RemittanceAdviceFields,
    RemittanceAdviceFieldsLineItems,
    RemittanceAdviceFieldsLineItemsTypedDict,
    RemittanceAdviceFieldsTypedDict,
    RemittanceAdviceFieldsVendor,
    RemittanceAdviceFieldsVendorTypedDict,
)
from .seawaybill import (
    SeaWaybill,
    SeaWaybillTypedDict,
    SeaWaybillValidationErrors,
    SeaWaybillValidationErrorsTypedDict,
)
from .seawaybillfields import (
    FreightAndCharges,
    FreightAndChargesTypedDict,
    SeaWaybillFields,
    SeaWaybillFieldsConsignee,
    SeaWaybillFieldsConsigneeTypedDict,
    SeaWaybillFieldsContainers,
    SeaWaybillFieldsContainersTypedDict,
    SeaWaybillFieldsLineItems,
    SeaWaybillFieldsLineItemsTypedDict,
    SeaWaybillFieldsNotifyParty,
    SeaWaybillFieldsNotifyPartyTypedDict,
    SeaWaybillFieldsShipper,
    SeaWaybillFieldsShipperTypedDict,
    SeaWaybillFieldsTotals,
    SeaWaybillFieldsTotalsTypedDict,
    SeaWaybillFieldsTypedDict,
)
from .security import Security, SecurityTypedDict
from .taxireceipt import (
    TaxiReceipt,
    TaxiReceiptTypedDict,
    TaxiReceiptValidationErrors,
    TaxiReceiptValidationErrorsTypedDict,
)
from .taxireceiptfields import (
    PaymentMethod1,
    PaymentMethod2,
    PaymentMethod3,
    PaymentMethod4,
    PaymentMethod5,
    TaxiReceiptFields,
    TaxiReceiptFieldsCardType,
    TaxiReceiptFieldsCardType1,
    TaxiReceiptFieldsCardType2,
    TaxiReceiptFieldsCardType3,
    TaxiReceiptFieldsCardType4,
    TaxiReceiptFieldsCardType5,
    TaxiReceiptFieldsCardTypeTypedDict,
    TaxiReceiptFieldsCreditOrDebit,
    TaxiReceiptFieldsCreditOrDebit1,
    TaxiReceiptFieldsCreditOrDebit2,
    TaxiReceiptFieldsCreditOrDebitTypedDict,
    TaxiReceiptFieldsPaymentMethod,
    TaxiReceiptFieldsPaymentMethodTypedDict,
    TaxiReceiptFieldsTaxes,
    TaxiReceiptFieldsTaxesTypedDict,
    TaxiReceiptFieldsTypedDict,
)
from .toomanyrequestserror import TooManyRequestsError, TooManyRequestsErrorData
from .unauthorizederror import UnauthorizedError, UnauthorizedErrorData
from .unsupportedmediatypeerror import (
    UnsupportedMediaTypeError,
    UnsupportedMediaTypeErrorData,
)
from .urlinputsource import URLInputSource, URLInputSourceTypedDict
from .urllistinputsource import URLListInputSource, URLListInputSourceTypedDict
from .usform1040 import (
    UsForm1040,
    UsForm1040TypedDict,
    UsForm1040ValidationErrors,
    UsForm1040ValidationErrorsTypedDict,
)
from .usform1040fields import (
    Address,
    AddressTypedDict,
    AdjustmentsToIncomeGroup,
    AdjustmentsToIncomeGroupTypedDict,
    AgeOrBlindness,
    AgeOrBlindnessTypedDict,
    AnotherPersonCanDiscussWithIrs,
    AnotherPersonCanDiscussWithIrsTypedDict,
    Box16Group,
    Box16GroupTypedDict,
    Box1Group,
    Box1GroupTypedDict,
    Box25GroupFederalIncomeTax,
    Box25GroupFederalIncomeTaxTypedDict,
    Box2Group,
    Box2GroupTypedDict,
    Box35Group,
    Box35GroupTypedDict,
    Box35cType,
    Box35cTypeTypedDict,
    Box3Group,
    Box3GroupTypedDict,
    Box4Group,
    Box4GroupTypedDict,
    Box5Group,
    Box5GroupTypedDict,
    Box6Group,
    Box6GroupTypedDict,
    Box7Group,
    Box7GroupTypedDict,
    CapitalGainOrLossGroup,
    CapitalGainOrLossGroupTypedDict,
    ChildTaxCreditGroup,
    ChildTaxCreditGroupTypedDict,
    Dependents,
    DependentsTypedDict,
    DigitalAssets,
    DigitalAssetsTypedDict,
    DividendsGroup,
    DividendsGroupTypedDict,
    EarnedIncomeCreditGroup,
    EarnedIncomeCreditGroupTypedDict,
    FederalIncomeTaxGroup,
    FederalIncomeTaxGroupTypedDict,
    FilingStatus,
    FilingStatusTypedDict,
    FinancialInterestInVirtualCurrencyDuringThisYear,
    FinancialInterestInVirtualCurrencyDuringThisYearTypedDict,
    Form,
    FormTypedDict,
    IraDistributionsGroup,
    IraDistributionsGroupTypedDict,
    IrasPensionsAndAnnuitiesGroupOutdated,
    IrasPensionsAndAnnuitiesGroupOutdatedTypedDict,
    PensionsAndAnnuitiesGroup,
    PensionsAndAnnuitiesGroupTypedDict,
    Preparer,
    PreparerTypedDict,
    PresidentialElectionCampaign,
    PresidentialElectionCampaignTypedDict,
    RefundGroup,
    RefundGroupTypedDict,
    Signature,
    SignatureTypedDict,
    SocialSecurityBenefitsGroup,
    SocialSecurityBenefitsGroupTypedDict,
    SomeoneCanClaim,
    SomeoneCanClaimTypedDict,
    Spouse,
    SpouseTypedDict,
    SpousesSignature,
    SpousesSignatureTypedDict,
    StandardDeduction,
    StandardDeductionTypedDict,
    TaxExemptInterestGroup,
    TaxExemptInterestGroupTypedDict,
    TaxGroup,
    TaxGroupTypedDict,
    TaxableIncomeGroup,
    TaxableIncomeGroupTypedDict,
    ThirdPartyDesignee,
    ThirdPartyDesigneeTypedDict,
    Type,
    TypeTypedDict,
    USForm10402018to2022,
    USForm10402018to2022TypedDict,
    USForm10402022,
    USForm10402022TypedDict,
    USForm1040Fields,
    USForm1040Fields1Spouse,
    USForm1040Fields1SpouseTypedDict,
    USForm1040Fields2Spouse,
    USForm1040Fields2SpouseTypedDict,
    USForm1040FieldsAddress,
    USForm1040FieldsAddressTypedDict,
    USForm1040FieldsAgeOrBlindness,
    USForm1040FieldsAgeOrBlindnessTypedDict,
    USForm1040FieldsAnotherPersonCanDiscussWithIrs,
    USForm1040FieldsAnotherPersonCanDiscussWithIrsTypedDict,
    USForm1040FieldsDependents,
    USForm1040FieldsDependentsTypedDict,
    USForm1040FieldsFilingStatus,
    USForm1040FieldsFilingStatusTypedDict,
    USForm1040FieldsForm,
    USForm1040FieldsFormTypedDict,
    USForm1040FieldsPreparer,
    USForm1040FieldsPreparerTypedDict,
    USForm1040FieldsPresidentialElectionCampaign,
    USForm1040FieldsPresidentialElectionCampaignTypedDict,
    USForm1040FieldsSignature,
    USForm1040FieldsSignatureTypedDict,
    USForm1040FieldsSomeoneCanClaim,
    USForm1040FieldsSomeoneCanClaimTypedDict,
    USForm1040FieldsSpouse,
    USForm1040FieldsSpouseTypedDict,
    USForm1040FieldsSpousesSignature,
    USForm1040FieldsSpousesSignatureTypedDict,
    USForm1040FieldsStandardDeduction,
    USForm1040FieldsStandardDeductionTypedDict,
    USForm1040FieldsThirdPartyDesignee,
    USForm1040FieldsThirdPartyDesigneeTypedDict,
    USForm1040FieldsTypedDict,
    USForm1040FieldsYou,
    USForm1040FieldsYouTypedDict,
    You,
    YouTypedDict,
)
from .usformw2 import (
    UsFormW2,
    UsFormW2TypedDict,
    UsFormW2ValidationErrors,
    UsFormW2ValidationErrorsTypedDict,
)
from .usformw2fields import (
    Boxes1520,
    Boxes1520TypedDict,
    USFormW2Fields,
    USFormW2FieldsTypedDict,
)
from .utilitybill import (
    UtilityBill,
    UtilityBillTypedDict,
    UtilityBillValidationErrors,
    UtilityBillValidationErrorsTypedDict,
)
from .utilitybillfields import (
    Adjustments,
    AdjustmentsTypedDict,
    BillingPeriod,
    BillingPeriodTypedDict,
    Issuer,
    IssuerTypedDict,
    RemitTo,
    RemitToTypedDict,
    UtilityBillFields,
    UtilityBillFieldsCustomer,
    UtilityBillFieldsCustomerTypedDict,
    UtilityBillFieldsLineItems,
    UtilityBillFieldsLineItemsTypedDict,
    UtilityBillFieldsTypedDict,
)


__all__ = [
    "APIError",
    "AccountCoOwnerName",
    "AccountCoOwnerNameTypedDict",
    "AdditionalCosts",
    "AdditionalCostsTypedDict",
    "Address",
    "AddressTypedDict",
    "Adjustments",
    "AdjustmentsToIncomeGroup",
    "AdjustmentsToIncomeGroupTypedDict",
    "AdjustmentsTypedDict",
    "Advisor",
    "AdvisorTypedDict",
    "AgeOrBlindness",
    "AgeOrBlindnessTypedDict",
    "AirWaybill",
    "AirWaybillFields",
    "AirWaybillFieldsLineItems",
    "AirWaybillFieldsLineItemsTypedDict",
    "AirWaybillFieldsTypedDict",
    "AirWaybillNumber",
    "AirWaybillNumberTypedDict",
    "AirWaybillTypedDict",
    "AirWaybillValidationErrors",
    "AirWaybillValidationErrorsTypedDict",
    "Airline",
    "AirlineTypedDict",
    "AirportOfDeparture",
    "AirportOfDepartureTypedDict",
    "AirportOfDestination",
    "AirportOfDestinationTypedDict",
    "Aligning",
    "Amount",
    "AmountTypedDict",
    "Amounts",
    "AmountsTypedDict",
    "AnotherPersonCanDiscussWithIrs",
    "AnotherPersonCanDiscussWithIrsTypedDict",
    "ArrivalNotice",
    "ArrivalNoticeFields",
    "ArrivalNoticeFieldsBillTo",
    "ArrivalNoticeFieldsBillToTypedDict",
    "ArrivalNoticeFieldsConsignee",
    "ArrivalNoticeFieldsConsigneeTypedDict",
    "ArrivalNoticeFieldsShipper",
    "ArrivalNoticeFieldsShipperTypedDict",
    "ArrivalNoticeFieldsTypedDict",
    "ArrivalNoticeTypedDict",
    "ArrivalNoticeValidationErrors",
    "ArrivalNoticeValidationErrorsTypedDict",
    "B",
    "BadRequestError",
    "BadRequestErrorData",
    "BankStatement",
    "BankStatementFields",
    "BankStatementFieldsTypedDict",
    "BankStatementTypedDict",
    "BankStatementValidationErrors",
    "BankStatementValidationErrorsTypedDict",
    "Barcodes",
    "BarcodesTypedDict",
    "BasicContract",
    "BasicContractFields",
    "BasicContractFieldsTypedDict",
    "BasicContractTypedDict",
    "BasicContractValidationErrors",
    "BasicContractValidationErrorsTypedDict",
    "BeginAirWaybillFieldExtractionRequestBody",
    "BeginAirWaybillFieldExtractionRequestBodyTypedDict",
    "BeginAirWaybillFieldExtractionResponse",
    "BeginAirWaybillFieldExtractionResponseTypedDict",
    "BeginArrivalNoticeFieldExtractionRequestBody",
    "BeginArrivalNoticeFieldExtractionRequestBodyTypedDict",
    "BeginArrivalNoticeFieldExtractionResponse",
    "BeginArrivalNoticeFieldExtractionResponseTypedDict",
    "BeginBankStatementFieldExtractionRequestBody",
    "BeginBankStatementFieldExtractionRequestBodyTypedDict",
    "BeginBankStatementFieldExtractionResponse",
    "BeginBankStatementFieldExtractionResponseTypedDict",
    "BeginBasicContractFieldExtractionRequestBody",
    "BeginBasicContractFieldExtractionRequestBodyTypedDict",
    "BeginBasicContractFieldExtractionResponse",
    "BeginBasicContractFieldExtractionResponseTypedDict",
    "BeginBillOfLadingFieldExtractionRequestBody",
    "BeginBillOfLadingFieldExtractionRequestBodyTypedDict",
    "BeginBillOfLadingFieldExtractionResponse",
    "BeginBillOfLadingFieldExtractionResponseTypedDict",
    "BeginBrokerageStatementFieldExtractionRequestBody",
    "BeginBrokerageStatementFieldExtractionRequestBodyTypedDict",
    "BeginBrokerageStatementFieldExtractionResponse",
    "BeginBrokerageStatementFieldExtractionResponseTypedDict",
    "BeginCertificateOfOriginFieldExtractionRequestBody",
    "BeginCertificateOfOriginFieldExtractionRequestBodyTypedDict",
    "BeginCertificateOfOriginFieldExtractionResponse",
    "BeginCertificateOfOriginFieldExtractionResponseTypedDict",
    "BeginCommercialInvoiceFieldExtractionRequestBody",
    "BeginCommercialInvoiceFieldExtractionRequestBodyTypedDict",
    "BeginCommercialInvoiceFieldExtractionResponse",
    "BeginCommercialInvoiceFieldExtractionResponseTypedDict",
    "BeginCustomsDeclarationFieldExtractionRequestBody",
    "BeginCustomsDeclarationFieldExtractionRequestBodyTypedDict",
    "BeginCustomsDeclarationFieldExtractionResponse",
    "BeginCustomsDeclarationFieldExtractionResponseTypedDict",
    "BeginDangerousGoodsDeclarationFieldExtractionRequestBody",
    "BeginDangerousGoodsDeclarationFieldExtractionRequestBodyTypedDict",
    "BeginDangerousGoodsDeclarationFieldExtractionResponse",
    "BeginDangerousGoodsDeclarationFieldExtractionResponseTypedDict",
    "BeginDeliveryNoteFieldExtractionRequestBody",
    "BeginDeliveryNoteFieldExtractionRequestBodyTypedDict",
    "BeginDeliveryNoteFieldExtractionResponse",
    "BeginDeliveryNoteFieldExtractionResponseTypedDict",
    "BeginDocumentConversionDocumentConversionRequestBody",
    "BeginDocumentConversionDocumentConversionRequestBodyTypedDict",
    "BeginDocumentConversionDocumentConversionResponse",
    "BeginDocumentConversionDocumentConversionResponseTypedDict",
    "BeginHotelInvoiceFieldExtractionRequestBody",
    "BeginHotelInvoiceFieldExtractionRequestBodyTypedDict",
    "BeginHotelInvoiceFieldExtractionResponse",
    "BeginHotelInvoiceFieldExtractionResponseTypedDict",
    "BeginImageToTextTextExtractionRequestBody",
    "BeginImageToTextTextExtractionRequestBodyLanguages",
    "BeginImageToTextTextExtractionRequestBodyOptions",
    "BeginImageToTextTextExtractionRequestBodyOptionsTypedDict",
    "BeginImageToTextTextExtractionRequestBodyTypedDict",
    "BeginImageToTextTextExtractionResponse",
    "BeginImageToTextTextExtractionResponseTypedDict",
    "BeginInternationalConsignmentNoteFieldExtractionRequestBody",
    "BeginInternationalConsignmentNoteFieldExtractionRequestBodyTypedDict",
    "BeginInternationalConsignmentNoteFieldExtractionResponse",
    "BeginInternationalConsignmentNoteFieldExtractionResponseTypedDict",
    "BeginInvoiceFieldExtractionRequestBody",
    "BeginInvoiceFieldExtractionRequestBodyTypedDict",
    "BeginInvoiceFieldExtractionResponse",
    "BeginInvoiceFieldExtractionResponseTypedDict",
    "BeginPackingListFieldExtractionRequestBody",
    "BeginPackingListFieldExtractionRequestBodyTypedDict",
    "BeginPackingListFieldExtractionResponse",
    "BeginPackingListFieldExtractionResponseTypedDict",
    "BeginPersonalEarningsStatementFieldExtractionRequestBody",
    "BeginPersonalEarningsStatementFieldExtractionRequestBodyTypedDict",
    "BeginPersonalEarningsStatementFieldExtractionResponse",
    "BeginPersonalEarningsStatementFieldExtractionResponseTypedDict",
    "BeginPurchaseOrderFieldExtractionRequestBody",
    "BeginPurchaseOrderFieldExtractionRequestBodyTypedDict",
    "BeginPurchaseOrderFieldExtractionResponse",
    "BeginPurchaseOrderFieldExtractionResponseTypedDict",
    "BeginReceiptFieldExtractionRequestBody",
    "BeginReceiptFieldExtractionRequestBodyTypedDict",
    "BeginReceiptFieldExtractionResponse",
    "BeginReceiptFieldExtractionResponseTypedDict",
    "BeginRemittanceAdviceFieldExtractionRequestBody",
    "BeginRemittanceAdviceFieldExtractionRequestBodyTypedDict",
    "BeginRemittanceAdviceFieldExtractionResponse",
    "BeginRemittanceAdviceFieldExtractionResponseTypedDict",
    "BeginSeaWaybillFieldExtractionRequestBody",
    "BeginSeaWaybillFieldExtractionRequestBodyTypedDict",
    "BeginSeaWaybillFieldExtractionResponse",
    "BeginSeaWaybillFieldExtractionResponseTypedDict",
    "BeginTaxiReceiptFieldExtractionRequestBody",
    "BeginTaxiReceiptFieldExtractionRequestBodyTypedDict",
    "BeginTaxiReceiptFieldExtractionResponse",
    "BeginTaxiReceiptFieldExtractionResponseTypedDict",
    "BeginUsForm1040FieldExtractionRequestBody",
    "BeginUsForm1040FieldExtractionRequestBodyTypedDict",
    "BeginUsForm1040FieldExtractionResponse",
    "BeginUsForm1040FieldExtractionResponseTypedDict",
    "BeginUsFormW2FieldExtractionRequestBody",
    "BeginUsFormW2FieldExtractionRequestBodyTypedDict",
    "BeginUsFormW2FieldExtractionResponse",
    "BeginUsFormW2FieldExtractionResponseTypedDict",
    "BeginUtilityBillFieldExtractionRequestBody",
    "BeginUtilityBillFieldExtractionRequestBodyTypedDict",
    "BeginUtilityBillFieldExtractionResponse",
    "BeginUtilityBillFieldExtractionResponseTypedDict",
    "BillOfLading",
    "BillOfLadingFields",
    "BillOfLadingFieldsBillTo",
    "BillOfLadingFieldsBillToTypedDict",
    "BillOfLadingFieldsCarrier",
    "BillOfLadingFieldsCarrierTypedDict",
    "BillOfLadingFieldsConsignee",
    "BillOfLadingFieldsConsigneeTypedDict",
    "BillOfLadingFieldsShipper",
    "BillOfLadingFieldsShipperTypedDict",
    "BillOfLadingFieldsTerms",
    "BillOfLadingFieldsTermsTypedDict",
    "BillOfLadingFieldsTypedDict",
    "BillOfLadingTypedDict",
    "BillOfLadingValidationErrors",
    "BillOfLadingValidationErrorsTypedDict",
    "BillTo",
    "BillToTypedDict",
    "BillingPeriod",
    "BillingPeriodTypedDict",
    "BlockType",
    "Borders",
    "BordersTypedDict",
    "Box16Group",
    "Box16GroupTypedDict",
    "Box1Group",
    "Box1GroupTypedDict",
    "Box25GroupFederalIncomeTax",
    "Box25GroupFederalIncomeTaxTypedDict",
    "Box2Group",
    "Box2GroupTypedDict",
    "Box35Group",
    "Box35GroupTypedDict",
    "Box35cType",
    "Box35cTypeTypedDict",
    "Box3Group",
    "Box3GroupTypedDict",
    "Box4Group",
    "Box4GroupTypedDict",
    "Box5Group",
    "Box5GroupTypedDict",
    "Box6Group",
    "Box6GroupTypedDict",
    "Box7Group",
    "Box7GroupTypedDict",
    "Boxes1520",
    "Boxes1520TypedDict",
    "Broker",
    "BrokerTypedDict",
    "BrokerageStatement",
    "BrokerageStatementFields",
    "BrokerageStatementFieldsTypedDict",
    "BrokerageStatementTypedDict",
    "BrokerageStatementValidationErrors",
    "BrokerageStatementValidationErrorsTypedDict",
    "BusinessUnit",
    "BusinessUnitTypedDict",
    "Buyer",
    "BuyerTypedDict",
    "CapitalGainOrLossGroup",
    "CapitalGainOrLossGroupTypedDict",
    "CardType",
    "CardType1",
    "CardType2",
    "CardType3",
    "CardType4",
    "CardType5",
    "CardTypeTypedDict",
    "Carrier",
    "CarrierTypedDict",
    "CarriersAgent",
    "CarriersAgentTypedDict",
    "Cells",
    "CellsTypedDict",
    "CertificateOfOrigin",
    "CertificateOfOriginFields",
    "CertificateOfOriginFieldsConsignee",
    "CertificateOfOriginFieldsConsigneeTypedDict",
    "CertificateOfOriginFieldsLineItems",
    "CertificateOfOriginFieldsLineItemsTypedDict",
    "CertificateOfOriginFieldsTypedDict",
    "CertificateOfOriginTypedDict",
    "CertificateOfOriginValidationErrors",
    "CertificateOfOriginValidationErrorsTypedDict",
    "Certification",
    "CertificationTypedDict",
    "CharParams",
    "CharParamsTypedDict",
    "Charges",
    "ChargesTypedDict",
    "Chars",
    "CharsTypedDict",
    "Checkmarks",
    "CheckmarksTypedDict",
    "ChildTaxCreditGroup",
    "ChildTaxCreditGroupTypedDict",
    "Client",
    "ClientTypedDict",
    "ColRowPosition",
    "ColRowPositionTypedDict",
    "CommercialInvoice",
    "CommercialInvoiceFields",
    "CommercialInvoiceFieldsAdditionalCosts",
    "CommercialInvoiceFieldsAdditionalCostsTypedDict",
    "CommercialInvoiceFieldsBillTo",
    "CommercialInvoiceFieldsBillToTypedDict",
    "CommercialInvoiceFieldsConsignee",
    "CommercialInvoiceFieldsConsigneeTypedDict",
    "CommercialInvoiceFieldsLineItems",
    "CommercialInvoiceFieldsLineItemsTypedDict",
    "CommercialInvoiceFieldsShipTo",
    "CommercialInvoiceFieldsShipToTypedDict",
    "CommercialInvoiceFieldsTypedDict",
    "CommercialInvoiceFieldsVendor",
    "CommercialInvoiceFieldsVendorTypedDict",
    "CommercialInvoiceTypedDict",
    "CommercialInvoiceValidationErrors",
    "CommercialInvoiceValidationErrorsTypedDict",
    "Comparison",
    "Comparison1",
    "Comparison2",
    "Comparison3",
    "Comparison4",
    "Consignee",
    "ConsigneeTypedDict",
    "Consignor",
    "ConsignorTypedDict",
    "Containers",
    "ContainersNotInTable",
    "ContainersNotInTableTypedDict",
    "ContainersTypedDict",
    "Content",
    "ContentTooLargeError",
    "ContentTooLargeErrorData",
    "ContentType",
    "ContentTypedDict",
    "ControlByOfficeOfDispatch",
    "ControlByOfficeOfDispatchTypedDict",
    "ConversionResults",
    "ConversionResultsTypedDict",
    "CreditOrDebit",
    "CreditOrDebit1",
    "CreditOrDebit2",
    "CreditOrDebitTypedDict",
    "Customer",
    "CustomerTypedDict",
    "CustomsDeclaration",
    "CustomsDeclarationFields",
    "CustomsDeclarationFieldsConsignee",
    "CustomsDeclarationFieldsConsigneeTypedDict",
    "CustomsDeclarationFieldsTypedDict",
    "CustomsDeclarationTypedDict",
    "CustomsDeclarationValidationErrors",
    "CustomsDeclarationValidationErrorsTypedDict",
    "DangerousGoodsDeclaration",
    "DangerousGoodsDeclarationFields",
    "DangerousGoodsDeclarationFieldsCarrier",
    "DangerousGoodsDeclarationFieldsCarrierTypedDict",
    "DangerousGoodsDeclarationFieldsConsignee",
    "DangerousGoodsDeclarationFieldsConsigneeTypedDict",
    "DangerousGoodsDeclarationFieldsLineItems",
    "DangerousGoodsDeclarationFieldsLineItemsTypedDict",
    "DangerousGoodsDeclarationFieldsShipper",
    "DangerousGoodsDeclarationFieldsShipperTypedDict",
    "DangerousGoodsDeclarationFieldsTypedDict",
    "DangerousGoodsDeclarationTypedDict",
    "DangerousGoodsDeclarationValidationErrors",
    "DangerousGoodsDeclarationValidationErrorsTypedDict",
    "Declarant",
    "DeclarantTypedDict",
    "DeclarationType",
    "DeclarationTypeTypedDict",
    "DeleteDocumentRequest",
    "DeleteDocumentRequestTypedDict",
    "DeleteDocumentResponse",
    "DeleteDocumentResponseTypedDict",
    "DeliveryNote",
    "DeliveryNoteFields",
    "DeliveryNoteFieldsBillTo",
    "DeliveryNoteFieldsBillToTypedDict",
    "DeliveryNoteFieldsBuyer",
    "DeliveryNoteFieldsBuyerTypedDict",
    "DeliveryNoteFieldsLineItems",
    "DeliveryNoteFieldsLineItemsTypedDict",
    "DeliveryNoteFieldsShipTo",
    "DeliveryNoteFieldsShipToTypedDict",
    "DeliveryNoteFieldsTaxes",
    "DeliveryNoteFieldsTaxesTypedDict",
    "DeliveryNoteFieldsTypedDict",
    "DeliveryNoteFieldsVendor",
    "DeliveryNoteFieldsVendorTypedDict",
    "DeliveryNoteTypedDict",
    "DeliveryNoteValidationErrors",
    "DeliveryNoteValidationErrorsTypedDict",
    "Dependents",
    "DependentsTypedDict",
    "DigitalAssets",
    "DigitalAssetsTypedDict",
    "Dimensions",
    "DimensionsTypedDict",
    "Discharge",
    "DischargeTypedDict",
    "DividendsGroup",
    "DividendsGroupTypedDict",
    "Document",
    "DocumentConversionOutputFormat",
    "DocumentTypedDict",
    "DownloadDocumentConversionConvertedDocumentRequest",
    "DownloadDocumentConversionConvertedDocumentRequestTypedDict",
    "DownloadDocumentConversionConvertedDocumentResponse",
    "DownloadDocumentConversionConvertedDocumentResponseTypedDict",
    "EarnedIncomeCreditGroup",
    "EarnedIncomeCreditGroupTypedDict",
    "Eight",
    "EightTypedDict",
    "Eleven",
    "ElevenTypedDict",
    "EndPoints",
    "EndPointsTypedDict",
    "Errors",
    "ErrorsTypedDict",
    "ExpenseType",
    "ExpenseTypeTypedDict",
    "Exporter",
    "ExporterTypedDict",
    "ExtractedText",
    "ExtractedTextCharParams",
    "ExtractedTextCharParamsTypedDict",
    "ExtractedTextChars",
    "ExtractedTextCharsTypedDict",
    "ExtractedTextLines",
    "ExtractedTextLinesTypedDict",
    "ExtractedTextPosition",
    "ExtractedTextPositionTypedDict",
    "ExtractedTextTextLayoutPagesPosition",
    "ExtractedTextTextLayoutPagesPositionTypedDict",
    "ExtractedTextTextLayoutPagesSeparatorsPosition",
    "ExtractedTextTextLayoutPagesSeparatorsPositionTypedDict",
    "ExtractedTextTextLayoutPagesTablesCellsLinesPosition",
    "ExtractedTextTextLayoutPagesTablesCellsLinesPositionTypedDict",
    "ExtractedTextTextLayoutPagesTablesCellsLinesWordsPosition",
    "ExtractedTextTextLayoutPagesTablesCellsLinesWordsPositionTypedDict",
    "ExtractedTextTextLayoutPagesTablesCellsPosition",
    "ExtractedTextTextLayoutPagesTablesCellsPositionTypedDict",
    "ExtractedTextTextLayoutPagesTablesPosition",
    "ExtractedTextTextLayoutPagesTablesPositionTypedDict",
    "ExtractedTextTextLayoutPagesTextsLinesPosition",
    "ExtractedTextTextLayoutPagesTextsLinesPositionTypedDict",
    "ExtractedTextTextLayoutPagesTextsLinesWordsPosition",
    "ExtractedTextTextLayoutPagesTextsLinesWordsPositionTypedDict",
    "ExtractedTextTextLayoutPagesTextsPosition",
    "ExtractedTextTextLayoutPagesTextsPositionTypedDict",
    "ExtractedTextTextLayoutPosition",
    "ExtractedTextTextLayoutPositionTypedDict",
    "ExtractedTextTextPosition",
    "ExtractedTextTextPositionTypedDict",
    "ExtractedTextTextType",
    "ExtractedTextType",
    "ExtractedTextTypedDict",
    "ExtractedTextWords",
    "ExtractedTextWordsTypedDict",
    "FederalIncomeTaxGroup",
    "FederalIncomeTaxGroupTypedDict",
    "FilingStatus",
    "FilingStatusTypedDict",
    "FinancialInterestInVirtualCurrencyDuringThisYear",
    "FinancialInterestInVirtualCurrencyDuringThisYearTypedDict",
    "Five",
    "FlightAndDate",
    "FlightAndDateTypedDict",
    "Form",
    "FormTypedDict",
    "Formatting",
    "FormattingTypedDict",
    "Forms",
    "FormsTypedDict",
    "Four",
    "FreightAndCharges",
    "FreightAndChargesTypedDict",
    "GetDocumentConversionConversionRequest",
    "GetDocumentConversionConversionRequestTypedDict",
    "GetDocumentConversionConversionResponse",
    "GetDocumentConversionConversionResponseTypedDict",
    "GetExtractedAirWaybillFieldsRequest",
    "GetExtractedAirWaybillFieldsRequestTypedDict",
    "GetExtractedAirWaybillFieldsResponse",
    "GetExtractedAirWaybillFieldsResponseTypedDict",
    "GetExtractedArrivalNoticeFieldsRequest",
    "GetExtractedArrivalNoticeFieldsRequestTypedDict",
    "GetExtractedArrivalNoticeFieldsResponse",
    "GetExtractedArrivalNoticeFieldsResponseTypedDict",
    "GetExtractedBankStatementFieldsRequest",
    "GetExtractedBankStatementFieldsRequestTypedDict",
    "GetExtractedBankStatementFieldsResponse",
    "GetExtractedBankStatementFieldsResponseTypedDict",
    "GetExtractedBasicContractFieldsRequest",
    "GetExtractedBasicContractFieldsRequestTypedDict",
    "GetExtractedBasicContractFieldsResponse",
    "GetExtractedBasicContractFieldsResponseTypedDict",
    "GetExtractedBillOfLadingFieldsRequest",
    "GetExtractedBillOfLadingFieldsRequestTypedDict",
    "GetExtractedBillOfLadingFieldsResponse",
    "GetExtractedBillOfLadingFieldsResponseTypedDict",
    "GetExtractedBrokerageStatementFieldsRequest",
    "GetExtractedBrokerageStatementFieldsRequestTypedDict",
    "GetExtractedBrokerageStatementFieldsResponse",
    "GetExtractedBrokerageStatementFieldsResponseTypedDict",
    "GetExtractedCertificateOfOriginFieldsRequest",
    "GetExtractedCertificateOfOriginFieldsRequestTypedDict",
    "GetExtractedCertificateOfOriginFieldsResponse",
    "GetExtractedCertificateOfOriginFieldsResponseTypedDict",
    "GetExtractedCommercialInvoiceFieldsRequest",
    "GetExtractedCommercialInvoiceFieldsRequestTypedDict",
    "GetExtractedCommercialInvoiceFieldsResponse",
    "GetExtractedCommercialInvoiceFieldsResponseTypedDict",
    "GetExtractedCustomsDeclarationFieldsRequest",
    "GetExtractedCustomsDeclarationFieldsRequestTypedDict",
    "GetExtractedCustomsDeclarationFieldsResponse",
    "GetExtractedCustomsDeclarationFieldsResponseTypedDict",
    "GetExtractedDangerousGoodsDeclarationFieldsRequest",
    "GetExtractedDangerousGoodsDeclarationFieldsRequestTypedDict",
    "GetExtractedDangerousGoodsDeclarationFieldsResponse",
    "GetExtractedDangerousGoodsDeclarationFieldsResponseTypedDict",
    "GetExtractedDeliveryNoteFieldsRequest",
    "GetExtractedDeliveryNoteFieldsRequestTypedDict",
    "GetExtractedDeliveryNoteFieldsResponse",
    "GetExtractedDeliveryNoteFieldsResponseTypedDict",
    "GetExtractedHotelInvoiceFieldsRequest",
    "GetExtractedHotelInvoiceFieldsRequestTypedDict",
    "GetExtractedHotelInvoiceFieldsResponse",
    "GetExtractedHotelInvoiceFieldsResponseTypedDict",
    "GetExtractedInternationalConsignmentNoteFieldsRequest",
    "GetExtractedInternationalConsignmentNoteFieldsRequestTypedDict",
    "GetExtractedInternationalConsignmentNoteFieldsResponse",
    "GetExtractedInternationalConsignmentNoteFieldsResponseTypedDict",
    "GetExtractedInvoiceFieldsRequest",
    "GetExtractedInvoiceFieldsRequestTypedDict",
    "GetExtractedInvoiceFieldsResponse",
    "GetExtractedInvoiceFieldsResponseTypedDict",
    "GetExtractedPackingListFieldsRequest",
    "GetExtractedPackingListFieldsRequestTypedDict",
    "GetExtractedPackingListFieldsResponse",
    "GetExtractedPackingListFieldsResponseTypedDict",
    "GetExtractedPersonalEarningsStatementFieldsRequest",
    "GetExtractedPersonalEarningsStatementFieldsRequestTypedDict",
    "GetExtractedPersonalEarningsStatementFieldsResponse",
    "GetExtractedPersonalEarningsStatementFieldsResponseTypedDict",
    "GetExtractedPurchaseOrderFieldsRequest",
    "GetExtractedPurchaseOrderFieldsRequestTypedDict",
    "GetExtractedPurchaseOrderFieldsResponse",
    "GetExtractedPurchaseOrderFieldsResponseTypedDict",
    "GetExtractedReceiptFieldsRequest",
    "GetExtractedReceiptFieldsRequestTypedDict",
    "GetExtractedReceiptFieldsResponse",
    "GetExtractedReceiptFieldsResponseTypedDict",
    "GetExtractedRemittanceAdviceFieldsRequest",
    "GetExtractedRemittanceAdviceFieldsRequestTypedDict",
    "GetExtractedRemittanceAdviceFieldsResponse",
    "GetExtractedRemittanceAdviceFieldsResponseTypedDict",
    "GetExtractedSeaWaybillFieldsRequest",
    "GetExtractedSeaWaybillFieldsRequestTypedDict",
    "GetExtractedSeaWaybillFieldsResponse",
    "GetExtractedSeaWaybillFieldsResponseTypedDict",
    "GetExtractedTaxiReceiptFieldsRequest",
    "GetExtractedTaxiReceiptFieldsRequestTypedDict",
    "GetExtractedTaxiReceiptFieldsResponse",
    "GetExtractedTaxiReceiptFieldsResponseTypedDict",
    "GetExtractedUsForm1040FieldsRequest",
    "GetExtractedUsForm1040FieldsRequestTypedDict",
    "GetExtractedUsForm1040FieldsResponse",
    "GetExtractedUsForm1040FieldsResponseTypedDict",
    "GetExtractedUsFormW2FieldsRequest",
    "GetExtractedUsFormW2FieldsRequestTypedDict",
    "GetExtractedUsFormW2FieldsResponse",
    "GetExtractedUsFormW2FieldsResponseTypedDict",
    "GetExtractedUtilityBillFieldsRequest",
    "GetExtractedUtilityBillFieldsRequestTypedDict",
    "GetExtractedUtilityBillFieldsResponse",
    "GetExtractedUtilityBillFieldsResponseTypedDict",
    "GetImageToTextExtractedTextRequest",
    "GetImageToTextExtractedTextRequestTypedDict",
    "GetImageToTextExtractedTextResponse",
    "GetImageToTextExtractedTextResponseTypedDict",
    "HTTPMetadata",
    "HTTPMetadataTypedDict",
    "HoldingsLevel",
    "HoldingsLevelTypedDict",
    "HotelInvoice",
    "HotelInvoiceFields",
    "HotelInvoiceFieldsLineItems",
    "HotelInvoiceFieldsLineItemsTypedDict",
    "HotelInvoiceFieldsTaxes",
    "HotelInvoiceFieldsTaxesTypedDict",
    "HotelInvoiceFieldsTypedDict",
    "HotelInvoiceTypedDict",
    "HotelInvoiceValidationErrors",
    "HotelInvoiceValidationErrorsTypedDict",
    "InputSource",
    "InputSourceTypedDict",
    "InternalServerError",
    "InternalServerErrorData",
    "InternationalConsignmentNote",
    "InternationalConsignmentNoteFields",
    "InternationalConsignmentNoteFieldsCarrier",
    "InternationalConsignmentNoteFieldsCarrierTypedDict",
    "InternationalConsignmentNoteFieldsConsignee",
    "InternationalConsignmentNoteFieldsConsigneeTypedDict",
    "InternationalConsignmentNoteFieldsLineItems",
    "InternationalConsignmentNoteFieldsLineItemsTypedDict",
    "InternationalConsignmentNoteFieldsShipper",
    "InternationalConsignmentNoteFieldsShipperTypedDict",
    "InternationalConsignmentNoteFieldsTotals",
    "InternationalConsignmentNoteFieldsTotalsTypedDict",
    "InternationalConsignmentNoteFieldsTypedDict",
    "InternationalConsignmentNoteTypedDict",
    "InternationalConsignmentNoteValidationErrors",
    "InternationalConsignmentNoteValidationErrorsTypedDict",
    "Invoice",
    "InvoiceData",
    "InvoiceDataTypedDict",
    "InvoiceFields",
    "InvoiceFieldsPurchaseOrder",
    "InvoiceFieldsPurchaseOrderTypedDict",
    "InvoiceFieldsTaxes",
    "InvoiceFieldsTaxesTypedDict",
    "InvoiceFieldsTypedDict",
    "InvoiceNumbers",
    "InvoiceNumbersTypedDict",
    "InvoiceType",
    "InvoiceTypeTypedDict",
    "InvoiceTypedDict",
    "InvoiceValidationErrors",
    "InvoiceValidationErrorsTypedDict",
    "IraDistributionsGroup",
    "IraDistributionsGroupTypedDict",
    "IrasPensionsAndAnnuitiesGroupOutdated",
    "IrasPensionsAndAnnuitiesGroupOutdatedTypedDict",
    "Issuer",
    "IssuerTypedDict",
    "L",
    "Languages",
    "Layout",
    "LayoutReferences",
    "LayoutReferencesTypedDict",
    "LayoutTypedDict",
    "LineItems",
    "LineItemsTypedDict",
    "Lines",
    "LinesTypedDict",
    "ListDocumentsRequest",
    "ListDocumentsRequestTypedDict",
    "ListDocumentsResponse",
    "ListDocumentsResponseTypedDict",
    "ListLevels",
    "ListLevelsTypedDict",
    "ListReference",
    "ListReferenceTypedDict",
    "Lists",
    "ListsTypedDict",
    "Loading",
    "LoadingTypedDict",
    "MeansOfTransportAndRoute",
    "MeansOfTransportAndRouteTypedDict",
    "Nine",
    "NineTypedDict",
    "NotFoundError",
    "NotFoundErrorData",
    "NotifyParty",
    "NotifyPartyTypedDict",
    "NumberingStyle",
    "One",
    "Options",
    "OptionsTypedDict",
    "Packages",
    "PackagesTypedDict",
    "PackingList",
    "PackingListFields",
    "PackingListFieldsBillTo",
    "PackingListFieldsBillToTypedDict",
    "PackingListFieldsBuyer",
    "PackingListFieldsBuyerTypedDict",
    "PackingListFieldsConsignee",
    "PackingListFieldsConsigneeTypedDict",
    "PackingListFieldsLineItems",
    "PackingListFieldsLineItemsTypedDict",
    "PackingListFieldsPurchaseOrder",
    "PackingListFieldsPurchaseOrderTypedDict",
    "PackingListFieldsShipper",
    "PackingListFieldsShipperTypedDict",
    "PackingListFieldsTypedDict",
    "PackingListTypedDict",
    "PackingListValidationErrors",
    "PackingListValidationErrorsTypedDict",
    "Pages",
    "PagesTypedDict",
    "Paragraphs",
    "ParagraphsTypedDict",
    "Params",
    "Params1",
    "Params1TypedDict",
    "Params2",
    "Params2TypedDict",
    "Params3",
    "Params3TypedDict",
    "Params4",
    "Params4TypedDict",
    "Params5",
    "Params5TypedDict",
    "Party",
    "PartyTypedDict",
    "PathParamDocumentConversionOutputFormat",
    "PaymentInformation",
    "PaymentInformationTypedDict",
    "PaymentMethod",
    "PaymentMethod1",
    "PaymentMethod2",
    "PaymentMethod3",
    "PaymentMethod4",
    "PaymentMethod5",
    "PaymentMethodTypedDict",
    "PaymentRequiredError",
    "PaymentRequiredErrorData",
    "PensionsAndAnnuitiesGroup",
    "PensionsAndAnnuitiesGroupTypedDict",
    "PersonalEarningsStatement",
    "PersonalEarningsStatementFields",
    "PersonalEarningsStatementFieldsTypedDict",
    "PersonalEarningsStatementTypedDict",
    "PersonalEarningsStatementValidationErrors",
    "PersonalEarningsStatementValidationErrorsTypedDict",
    "Pictures",
    "PicturesTypedDict",
    "PlaceAndDateOfTakingOverOfGoods",
    "PlaceAndDateOfTakingOverOfGoodsTypedDict",
    "PlaceOfDeliveryOfGoods",
    "PlaceOfDeliveryOfGoodsTypedDict",
    "Position",
    "PositionTypedDict",
    "Preparer",
    "PreparerTypedDict",
    "PresidentialElectionCampaign",
    "PresidentialElectionCampaignTypedDict",
    "ProblemDetail",
    "ProblemDetailData",
    "PurchaseOrder",
    "PurchaseOrderFields",
    "PurchaseOrderFieldsLineItems",
    "PurchaseOrderFieldsLineItemsTypedDict",
    "PurchaseOrderFieldsTaxes",
    "PurchaseOrderFieldsTaxesTypedDict",
    "PurchaseOrderFieldsTypedDict",
    "PurchaseOrderTypedDict",
    "PurchaseOrderValidationErrors",
    "PurchaseOrderValidationErrorsTypedDict",
    "R",
    "RawInputSource",
    "RawInputSourceTypedDict",
    "Receipt",
    "ReceiptFields",
    "ReceiptFieldsTypedDict",
    "ReceiptLineItem",
    "ReceiptLineItemTypedDict",
    "ReceiptTypedDict",
    "ReferenceNumber",
    "ReferenceNumberTypedDict",
    "RefundGroup",
    "RefundGroupTypedDict",
    "RemitTo",
    "RemitToTypedDict",
    "RemittanceAdvice",
    "RemittanceAdviceFields",
    "RemittanceAdviceFieldsLineItems",
    "RemittanceAdviceFieldsLineItemsTypedDict",
    "RemittanceAdviceFieldsTypedDict",
    "RemittanceAdviceFieldsVendor",
    "RemittanceAdviceFieldsVendorTypedDict",
    "RemittanceAdviceTypedDict",
    "RemittanceAdviceValidationErrors",
    "RemittanceAdviceValidationErrorsTypedDict",
    "Role",
    "Rotated",
    "SeaWaybill",
    "SeaWaybillFields",
    "SeaWaybillFieldsConsignee",
    "SeaWaybillFieldsConsigneeTypedDict",
    "SeaWaybillFieldsContainers",
    "SeaWaybillFieldsContainersTypedDict",
    "SeaWaybillFieldsLineItems",
    "SeaWaybillFieldsLineItemsTypedDict",
    "SeaWaybillFieldsNotifyParty",
    "SeaWaybillFieldsNotifyPartyTypedDict",
    "SeaWaybillFieldsShipper",
    "SeaWaybillFieldsShipperTypedDict",
    "SeaWaybillFieldsTotals",
    "SeaWaybillFieldsTotalsTypedDict",
    "SeaWaybillFieldsTypedDict",
    "SeaWaybillTypedDict",
    "SeaWaybillValidationErrors",
    "SeaWaybillValidationErrorsTypedDict",
    "Security",
    "SecurityTypedDict",
    "Separators",
    "SeparatorsTypedDict",
    "Seven",
    "SevenTypedDict",
    "ShipTo",
    "ShipToTypedDict",
    "Shipper",
    "ShipperTypedDict",
    "Signature",
    "SignatureTypedDict",
    "Six",
    "SixTypedDict",
    "SocialSecurityBenefitsGroup",
    "SocialSecurityBenefitsGroupTypedDict",
    "SomeoneCanClaim",
    "SomeoneCanClaimTypedDict",
    "Spouse",
    "SpouseTypedDict",
    "SpousesSignature",
    "SpousesSignatureTypedDict",
    "StandardDeduction",
    "StandardDeductionTypedDict",
    "Status",
    "SuccessiveCarrier",
    "SuccessiveCarrierTypedDict",
    "SupplementType",
    "Supplier",
    "SupplierTypedDict",
    "T",
    "Tables",
    "TablesTypedDict",
    "TaxExemptInterestGroup",
    "TaxExemptInterestGroupTypedDict",
    "TaxGroup",
    "TaxGroupTypedDict",
    "TaxRates",
    "TaxRatesTypedDict",
    "TaxableIncomeGroup",
    "TaxableIncomeGroupTypedDict",
    "Taxes",
    "TaxesTypedDict",
    "TaxiReceipt",
    "TaxiReceiptFields",
    "TaxiReceiptFieldsCardType",
    "TaxiReceiptFieldsCardType1",
    "TaxiReceiptFieldsCardType2",
    "TaxiReceiptFieldsCardType3",
    "TaxiReceiptFieldsCardType4",
    "TaxiReceiptFieldsCardType5",
    "TaxiReceiptFieldsCardTypeTypedDict",
    "TaxiReceiptFieldsCreditOrDebit",
    "TaxiReceiptFieldsCreditOrDebit1",
    "TaxiReceiptFieldsCreditOrDebit2",
    "TaxiReceiptFieldsCreditOrDebitTypedDict",
    "TaxiReceiptFieldsPaymentMethod",
    "TaxiReceiptFieldsPaymentMethodTypedDict",
    "TaxiReceiptFieldsTaxes",
    "TaxiReceiptFieldsTaxesTypedDict",
    "TaxiReceiptFieldsTypedDict",
    "TaxiReceiptTypedDict",
    "TaxiReceiptValidationErrors",
    "TaxiReceiptValidationErrorsTypedDict",
    "Ten",
    "TenTypedDict",
    "Terms",
    "TermsTypedDict",
    "Text",
    "TextTypedDict",
    "Texts",
    "TextsTypedDict",
    "ThirdPartyDesignee",
    "ThirdPartyDesigneeTypedDict",
    "Three",
    "TooManyRequestsError",
    "TooManyRequestsErrorData",
    "TotalDimensions",
    "TotalDimensionsTypedDict",
    "TotalGrossWeight",
    "TotalGrossWeightTypedDict",
    "TotalNetWeight",
    "TotalNetWeightTypedDict",
    "TotalPackages",
    "TotalPackagesTypedDict",
    "TotalQuantity",
    "TotalQuantityTypedDict",
    "TotalVolume",
    "TotalVolumeTypedDict",
    "Totals",
    "TotalsTypedDict",
    "Transactions",
    "TransactionsTypedDict",
    "Two",
    "Type",
    "TypeTypedDict",
    "URLInputSource",
    "URLInputSourceTypedDict",
    "URLListInputSource",
    "URLListInputSourceTypedDict",
    "USForm10402018to2022",
    "USForm10402018to2022TypedDict",
    "USForm10402022",
    "USForm10402022TypedDict",
    "USForm1040Fields",
    "USForm1040Fields1Spouse",
    "USForm1040Fields1SpouseTypedDict",
    "USForm1040Fields2Spouse",
    "USForm1040Fields2SpouseTypedDict",
    "USForm1040FieldsAddress",
    "USForm1040FieldsAddressTypedDict",
    "USForm1040FieldsAgeOrBlindness",
    "USForm1040FieldsAgeOrBlindnessTypedDict",
    "USForm1040FieldsAnotherPersonCanDiscussWithIrs",
    "USForm1040FieldsAnotherPersonCanDiscussWithIrsTypedDict",
    "USForm1040FieldsDependents",
    "USForm1040FieldsDependentsTypedDict",
    "USForm1040FieldsFilingStatus",
    "USForm1040FieldsFilingStatusTypedDict",
    "USForm1040FieldsForm",
    "USForm1040FieldsFormTypedDict",
    "USForm1040FieldsPreparer",
    "USForm1040FieldsPreparerTypedDict",
    "USForm1040FieldsPresidentialElectionCampaign",
    "USForm1040FieldsPresidentialElectionCampaignTypedDict",
    "USForm1040FieldsSignature",
    "USForm1040FieldsSignatureTypedDict",
    "USForm1040FieldsSomeoneCanClaim",
    "USForm1040FieldsSomeoneCanClaimTypedDict",
    "USForm1040FieldsSpouse",
    "USForm1040FieldsSpouseTypedDict",
    "USForm1040FieldsSpousesSignature",
    "USForm1040FieldsSpousesSignatureTypedDict",
    "USForm1040FieldsStandardDeduction",
    "USForm1040FieldsStandardDeductionTypedDict",
    "USForm1040FieldsThirdPartyDesignee",
    "USForm1040FieldsThirdPartyDesigneeTypedDict",
    "USForm1040FieldsTypedDict",
    "USForm1040FieldsYou",
    "USForm1040FieldsYouTypedDict",
    "USFormW2Fields",
    "USFormW2FieldsTypedDict",
    "UnauthorizedError",
    "UnauthorizedErrorData",
    "UnsupportedMediaTypeError",
    "UnsupportedMediaTypeErrorData",
    "UsForm1040",
    "UsForm1040TypedDict",
    "UsForm1040ValidationErrors",
    "UsForm1040ValidationErrorsTypedDict",
    "UsFormW2",
    "UsFormW2TypedDict",
    "UsFormW2ValidationErrors",
    "UsFormW2ValidationErrorsTypedDict",
    "UtilityBill",
    "UtilityBillFields",
    "UtilityBillFieldsCustomer",
    "UtilityBillFieldsCustomerTypedDict",
    "UtilityBillFieldsLineItems",
    "UtilityBillFieldsLineItemsTypedDict",
    "UtilityBillFieldsTypedDict",
    "UtilityBillTypedDict",
    "UtilityBillValidationErrors",
    "UtilityBillValidationErrorsTypedDict",
    "Validation",
    "ValidationContext",
    "ValidationErrors",
    "ValidationErrorsTypedDict",
    "ValidationTypedDict",
    "Value",
    "Vendor",
    "VendorTypedDict",
    "Volume",
    "VolumeTypedDict",
    "Weight",
    "WeightTypedDict",
    "Words",
    "WordsTypedDict",
    "You",
    "YouTypedDict",
]



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .rawinputsource import RawInputSource, RawInputSourceTypedDict
from .urlinputsource import URLInputSource, URLInputSourceTypedDict
from .urllistinputsource import URLListInputSource, URLListInputSourceTypedDict
from typing import Union
from typing_extensions import TypeAliasType


InputSourceTypedDict = TypeAliasType(
    "InputSourceTypedDict",
    Union[
        URLInputSourceTypedDict, URLListInputSourceTypedDict, RawInputSourceTypedDict
    ],
)
r"""The source of the document(s) to be processed"""


InputSource = TypeAliasType(
    "InputSource", Union[URLInputSource, URLListInputSource, RawInputSource]
)
r"""The source of the document(s) to be processed"""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from abbyy_document_ai.types import BaseModel
from datetime import date
import pydantic
from typing import List, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class ArrivalNoticeFieldsShipperTypedDict(TypedDict):
    name: NotRequired[str]
    r"""The shipper's name"""
    address: NotRequired[str]
    r"""The shipper's address"""


class ArrivalNoticeFieldsShipper(BaseModel):
    name: Optional[str] = None
    r"""The shipper's name"""

    address: Optional[str] = None
    r"""The shipper's address"""


class ArrivalNoticeFieldsConsigneeTypedDict(TypedDict):
    name: NotRequired[str]
    r"""The consignee's name"""
    address: NotRequired[str]
    r"""The consignee's address"""


class ArrivalNoticeFieldsConsignee(BaseModel):
    name: Optional[str] = None
    r"""The consignee's name"""

    address: Optional[str] = None
    r"""The consignee's address"""


class NotifyPartyTypedDict(TypedDict):
    name: NotRequired[str]
    r"""The name of the company to be notified of the arrival of the cargo"""
    address: NotRequired[str]
    r"""The address of the company to be notified of the arrival of the cargo"""


class NotifyParty(BaseModel):
    name: Optional[str] = None
    r"""The name of the company to be notified of the arrival of the cargo"""

    address: Optional[str] = None
    r"""The address of the company to be notified of the arrival of the cargo"""


class CarrierTypedDict(TypedDict):
    name: NotRequired[str]
    r"""The carrier's name"""
    scac_code: NotRequired[str]
    r"""The Standard Carrier Alpha Code"""


class Carrier(BaseModel):
    name: Optional[str] = None
    r"""The carrier's name"""

    scac_code: Annotated[Optional[str], pydantic.Field(alias="scacCode")] = None
    r"""The Standard Carrier Alpha Code"""


class ArrivalNoticeFieldsBillToTypedDict(TypedDict):
    r"""Information about the recipient of the invoice"""

    name: NotRequired[str]
    r"""The name of the recipient of the invoice"""
    address: NotRequired[str]
    r"""The address of the recipient of the invoice"""


class ArrivalNoticeFieldsBillTo(BaseModel):
    r"""Information about the recipient of the invoice"""

    name: Optional[str] = None
    r"""The name of the recipient of the invoice"""

    address: Optional[str] = None
    r"""The address of the recipient of the invoice"""


class ContainersNotInTableTypedDict(TypedDict):
    container_number: NotRequired[str]
    r"""The number of the container"""
    seal_number: NotRequired[str]
    r"""The number of the seal"""
    size_type: NotRequired[str]
    r"""The size and type of the container"""


class ContainersNotInTable(BaseModel):
    container_number: Annotated[
        Optional[str], pydantic.Field(alias="containerNumber")
    ] = None
    r"""The number of the container"""

    seal_number: Annotated[Optional[str], pydantic.Field(alias="sealNumber")] = None
    r"""The number of the seal"""

    size_type: Annotated[Optional[str], pydantic.Field(alias="sizeType")] = None
    r"""The size and type of the container"""


class ContainersTypedDict(TypedDict):
    container_number: NotRequired[str]
    r"""The number of the container"""
    seal_number: NotRequired[str]
    r"""The number of the seal"""
    seal_value: NotRequired[str]
    r"""The value of the seal"""
    size_type: NotRequired[str]
    r"""The size and type of the container"""
    number_of_packages: NotRequired[float]
    r"""The number of packages"""
    weight_metric: NotRequired[float]
    r"""The weight in metric units"""
    weight_uom_metric: NotRequired[str]
    r"""The unit of measurement used for the weight (kilos)"""
    weight_nonmetric: NotRequired[float]
    r"""The weight in non-metric units"""
    weight_uom_nonmetric: NotRequired[str]
    r"""The unit of measurement used for the weight (lbs)"""
    volume_metric: NotRequired[float]
    r"""The volume in metric units"""
    volume_uom_metric: NotRequired[str]
    r"""The unit of measurement used for the volume (cubic meters)"""
    volume_nonmetric: NotRequired[float]
    r"""The volume in non-metric units"""
    volume_uom_nonmetric: NotRequired[str]
    r"""The unit of measurement used for the volume (liters, cubic feet, etc.)"""
    arrival_date: NotRequired[str]
    r"""The arrival date"""


class Containers(BaseModel):
    container_number: Annotated[
        Optional[str], pydantic.Field(alias="containerNumber")
    ] = None
    r"""The number of the container"""

    seal_number: Annotated[Optional[str], pydantic.Field(alias="sealNumber")] = None
    r"""The number of the seal"""

    seal_value: Annotated[Optional[str], pydantic.Field(alias="sealValue")] = None
    r"""The value of the seal"""

    size_type: Annotated[Optional[str], pydantic.Field(alias="sizeType")] = None
    r"""The size and type of the container"""

    number_of_packages: Annotated[
        Optional[float], pydantic.Field(alias="numberOfPackages")
    ] = None
    r"""The number of packages"""

    weight_metric: Annotated[Optional[float], pydantic.Field(alias="weightMetric")] = (
        None
    )
    r"""The weight in metric units"""

    weight_uom_metric: Annotated[
        Optional[str], pydantic.Field(alias="weightUomMetric")
    ] = None
    r"""The unit of measurement used for the weight (kilos)"""

    weight_nonmetric: Annotated[
        Optional[float], pydantic.Field(alias="weightNonmetric")
    ] = None
    r"""The weight in non-metric units"""

    weight_uom_nonmetric: Annotated[
        Optional[str], pydantic.Field(alias="weightUomNonmetric")
    ] = None
    r"""The unit of measurement used for the weight (lbs)"""

    volume_metric: Annotated[Optional[float], pydantic.Field(alias="volumeMetric")] = (
        None
    )
    r"""The volume in metric units"""

    volume_uom_metric: Annotated[
        Optional[str], pydantic.Field(alias="volumeUomMetric")
    ] = None
    r"""The unit of measurement used for the volume (cubic meters)"""

    volume_nonmetric: Annotated[
        Optional[float], pydantic.Field(alias="volumeNonmetric")
    ] = None
    r"""The volume in non-metric units"""

    volume_uom_nonmetric: Annotated[
        Optional[str], pydantic.Field(alias="volumeUomNonmetric")
    ] = None
    r"""The unit of measurement used for the volume (liters, cubic feet, etc.)"""

    arrival_date: Annotated[Optional[str], pydantic.Field(alias="arrivalDate")] = None
    r"""The arrival date"""


class WeightTypedDict(TypedDict):
    weight_metric: NotRequired[float]
    r"""The total metric weight of all containers"""
    weight_uom_metric: NotRequired[str]
    r"""The unit of measurement used for the weight (kilos)"""
    weight_nonmetric: NotRequired[float]
    r"""The total nonmetric weight of all containers"""
    weight_uom_nonmetric: NotRequired[str]
    r"""The unit of measurement used for the weight (lbs)"""


class Weight(BaseModel):
    weight_metric: Annotated[Optional[float], pydantic.Field(alias="weightMetric")] = (
        None
    )
    r"""The total metric weight of all containers"""

    weight_uom_metric: Annotated[
        Optional[str], pydantic.Field(alias="weightUomMetric")
    ] = None
    r"""The unit of measurement used for the weight (kilos)"""

    weight_nonmetric: Annotated[
        Optional[float], pydantic.Field(alias="weightNonmetric")
    ] = None
    r"""The total nonmetric weight of all containers"""

    weight_uom_nonmetric: Annotated[
        Optional[str], pydantic.Field(alias="weightUomNonmetric")
    ] = None
    r"""The unit of measurement used for the weight (lbs)"""


class PackagesTypedDict(TypedDict):
    number_of_packages: NotRequired[float]
    r"""The total number of packages"""
    package_type: NotRequired[str]
    r"""The package type"""


class Packages(BaseModel):
    number_of_packages: Annotated[
        Optional[float], pydantic.Field(alias="numberOfPackages")
    ] = None
    r"""The total number of packages"""

    package_type: Annotated[Optional[str], pydantic.Field(alias="packageType")] = None
    r"""The package type"""


class VolumeTypedDict(TypedDict):
    volume_metric: NotRequired[float]
    r"""The total metric volume of all containers"""
    volume_uom_metric: NotRequired[str]
    r"""The unit of measurement used for the volume (cubic meters)"""
    volume_nonmetric: NotRequired[float]
    r"""The total nonmetric volume of all containers"""
    volume_uom_nonmetric: NotRequired[str]
    r"""The unit of measurement used for the volume (liters, cubic feet, etc.)"""


class Volume(BaseModel):
    volume_metric: Annotated[Optional[float], pydantic.Field(alias="volumeMetric")] = (
        None
    )
    r"""The total metric volume of all containers"""

    volume_uom_metric: Annotated[
        Optional[str], pydantic.Field(alias="volumeUomMetric")
    ] = None
    r"""The unit of measurement used for the volume (cubic meters)"""

    volume_nonmetric: Annotated[
        Optional[float], pydantic.Field(alias="volumeNonmetric")
    ] = None
    r"""The total nonmetric volume of all containers"""

    volume_uom_nonmetric: Annotated[
        Optional[str], pydantic.Field(alias="volumeUomNonmetric")
    ] = None
    r"""The unit of measurement used for the volume (liters, cubic feet, etc.)"""


class AmountTypedDict(TypedDict):
    total: NotRequired[float]
    r"""The total price of the goods"""
    currency: NotRequired[str]
    r"""The currency of the arrival notice"""


class Amount(BaseModel):
    total: Optional[float] = None
    r"""The total price of the goods"""

    currency: Optional[str] = None
    r"""The currency of the arrival notice"""


class TermsTypedDict(TypedDict):
    prepaid: NotRequired[bool]
    r"""Indicates if the transport expenses are charged to the shipper"""
    collect: NotRequired[bool]
    r"""Indicates if the transport expenses are charged to the consignee"""


class Terms(BaseModel):
    prepaid: Optional[bool] = None
    r"""Indicates if the transport expenses are charged to the shipper"""

    collect: Optional[bool] = None
    r"""Indicates if the transport expenses are charged to the consignee"""


class ArrivalNoticeFieldsTypedDict(TypedDict):
    r"""Fields extracted from an arrival notice"""

    shipper: NotRequired[ArrivalNoticeFieldsShipperTypedDict]
    consignee: NotRequired[ArrivalNoticeFieldsConsigneeTypedDict]
    notify_party: NotRequired[NotifyPartyTypedDict]
    carrier: NotRequired[CarrierTypedDict]
    bill_to: NotRequired[ArrivalNoticeFieldsBillToTypedDict]
    r"""Information about the recipient of the invoice"""
    date_: NotRequired[date]
    r"""The date of the arrival notice"""
    arrival_date: NotRequired[date]
    r"""The arrival date of the shipment"""
    bol_number: NotRequired[str]
    r"""The number of the bill of lading representing the ownership of the goods"""
    house_bol_number: NotRequired[str]
    r"""The number of the bill of lading created by an Ocean Transport Intermediary (OTI)"""
    purchase_order_number: NotRequired[str]
    r"""The number of the purchase order"""
    vessel_name: NotRequired[str]
    r"""The name of the ship"""
    voyage_number: NotRequired[str]
    r"""The number of the voyage carrying the goods"""
    port_of_loading: NotRequired[str]
    r"""The port where the goods are to be loaded"""
    port_of_discharge: NotRequired[str]
    r"""The port where the goods are to be discharged"""
    terminal: NotRequired[str]
    r"""Terminal at the port of discharge where the ship arrived"""
    place_of_receipt: NotRequired[str]
    r"""The place of receipt of the goods"""
    place_of_delivery: NotRequired[str]
    r"""The place of delivery of the goods"""
    containers_not_in_table: NotRequired[List[ContainersNotInTableTypedDict]]
    containers: NotRequired[List[ContainersTypedDict]]
    weight: NotRequired[WeightTypedDict]
    packages: NotRequired[PackagesTypedDict]
    volume: NotRequired[VolumeTypedDict]
    amount: NotRequired[AmountTypedDict]
    terms: NotRequired[TermsTypedDict]


class ArrivalNoticeFields(BaseModel):
    r"""Fields extracted from an arrival notice"""

    shipper: Optional[ArrivalNoticeFieldsShipper] = None

    consignee: Optional[ArrivalNoticeFieldsConsignee] = None

    notify_party: Annotated[
        Optional[NotifyParty], pydantic.Field(alias="notifyParty")
    ] = None

    carrier: Optional[Carrier] = None

    bill_to: Annotated[
        Optional[ArrivalNoticeFieldsBillTo], pydantic.Field(alias="billTo")
    ] = None
    r"""Information about the recipient of the invoice"""

    date_: Annotated[Optional[date], pydantic.Field(alias="date")] = None
    r"""The date of the arrival notice"""

    arrival_date: Annotated[Optional[date], pydantic.Field(alias="arrivalDate")] = None
    r"""The arrival date of the shipment"""

    bol_number: Annotated[Optional[str], pydantic.Field(alias="bolNumber")] = None
    r"""The number of the bill of lading representing the ownership of the goods"""

    house_bol_number: Annotated[
        Optional[str], pydantic.Field(alias="houseBolNumber")
    ] = None
    r"""The number of the bill of lading created by an Ocean Transport Intermediary (OTI)"""

    purchase_order_number: Annotated[
        Optional[str], pydantic.Field(alias="purchaseOrderNumber")
    ] = None
    r"""The number of the purchase order"""

    vessel_name: Annotated[Optional[str], pydantic.Field(alias="vesselName")] = None
    r"""The name of the ship"""

    voyage_number: Annotated[Optional[str], pydantic.Field(alias="voyageNumber")] = None
    r"""The number of the voyage carrying the goods"""

    port_of_loading: Annotated[Optional[str], pydantic.Field(alias="portOfLoading")] = (
        None
    )
    r"""The port where the goods are to be loaded"""

    port_of_discharge: Annotated[
        Optional[str], pydantic.Field(alias="portOfDischarge")
    ] = None
    r"""The port where the goods are to be discharged"""

    terminal: Optional[str] = None
    r"""Terminal at the port of discharge where the ship arrived"""

    place_of_receipt: Annotated[
        Optional[str], pydantic.Field(alias="placeOfReceipt")
    ] = None
    r"""The place of receipt of the goods"""

    place_of_delivery: Annotated[
        Optional[str], pydantic.Field(alias="placeOfDelivery")
    ] = None
    r"""The place of delivery of the goods"""

    containers_not_in_table: Annotated[
        Optional[List[ContainersNotInTable]],
        pydantic.Field(alias="containersNotInTable"),
    ] = None

    containers: Optional[List[Containers]] = None

    weight: Optional[Weight] = None

    packages: Optional[Packages] = None

    volume: Optional[Volume] = None

    amount: Optional[Amount] = None

    terms: Optional[Terms] = None
